@@ -55,7 +55,7 @@
 #include <Xm/ScrollFrameT.h>
 #include <Xm/TraitP.h>
 #include <Exm/Simple.h>
-#include <Exm/String.h>
+#include <Exm/ExmString.h>
 #include <Exm/StringTrans.h>
 #include <Exm/CommandB.h>
 #include <Exm/Grid.h>
