@@ -13,6 +13,7 @@
  *		INCLUDE FILES
  **************************************************************/
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <X11/Intrinsic.h>
 
@@ -53,6 +54,7 @@ static void OrientationCB(Widget, XtPointer, XtPointer);
 static void ConnectStyleCB(Widget, XtPointer, XtPointer);
 static void CompressStyleCB(Widget, XtPointer, XtPointer);
 static void ScaleCB(Widget, XtPointer, XtPointer);
+Pixmap XPM_PIXMAP(Widget w, char ** pixmapName);
 
 /**************************************************************
  *		GLOBALS
@@ -390,7 +392,7 @@ void WriteUpHype(Widget parent)
     xmstring = XmStringCreateLtoR(
 "The OpenMotif Tree Widget displays hierarchical data in a tree layout with a Motif\n\
 look and feel. The Tree widget displayed below contains entries corresponding\n\
-to EPak widgets. The nodes are XmPushButtons, but the tree can accept any type of widget.\n\
+to OpenMotif widgets. The nodes are XmPushButtons, but the tree can accept any type of widget.\n\
 \n\
 The Tree Widget uses \"constraints\" to arrange the children with the right layout.\n\
 To see the code to generate the tree below, press \"Show Layout Code...\".\n\
