@@ -14,6 +14,7 @@
 #include <stdio.h>
 #include <Xm/ButtonBoxP.h>
 #include <Xm/ExtP.h>
+#include "XmI.h"
 
 /************************************************************
  *       TYPEDEFS AND DEFINES
@@ -40,7 +41,8 @@
  ************************************************************/
 
 static void 	Initialize(Widget, Widget, ArgList, Cardinal *);
-static void	ClassInitialize(void), InsertChild(Widget);
+static void	ClassInitialize(void);
+static void	InsertChild(Widget);
 static void     Resize(Widget), ChangeManaged(Widget);
 static void 	ConstraintInitialize(Widget, Widget, ArgList, Cardinal *);
 
@@ -84,9 +86,9 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNmarginHeight, sizeof(Dimension), offset(margin_height),
-      _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels },
+      XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels },
     { XmNmarginWidth, sizeof(Dimension), offset(margin_width),
-      _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels },
+      XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels },
 };
 #undef offset
 	    
@@ -119,7 +121,7 @@ XmButtonBoxClassRec xmButtonBoxClassRec = {
     /* set_values_almost  */	XtInheritSetValuesAlmost,         
     /* get_values_hook    */	NULL,                             	
     /* accept_focus       */	NULL,                             
-    /* version            */	XtVersionDontCheck,
+    /* version            */	XtVersion,
     /* callback_private   */	NULL,                             
     /* tm_table           */	XtInheritTranslations, 
     /* query_geometry     */	(XtGeometryHandler) QueryGeometry, 
@@ -185,11 +187,13 @@ ClassInitialize()
 			    &XmButtonBox_offsets,
 			    &XmButtonBoxC_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
 			    &XmButtonBox_offsets);
     }
+    _XmProcessUnlock();
 
     XtSetTypeConverter(XmRString, XmRXmFillOption, 
 		       (XtTypeConverter) CvtStringToFillOption,
@@ -482,7 +486,7 @@ ChangeManaged(Widget w)
     * for Motif navigation
     */
 
-   _XmNavigChangeManaged(w);
+   XmeNavigChangeManaged(w);
 }
 
 
@@ -510,7 +514,14 @@ InsertChild(register Widget w)
      * superclass insert_child routine.
      */
 
-    (*SUPERCLASS->composite_class.insert_child)(w);
+    {
+       XtWidgetProc insert_child;
+       _XmProcessLock();
+       insert_child = ((XmManagerWidgetClass)xmManagerWidgetClass)->
+				composite_class.insert_child; 
+       _XmProcessUnlock();
+       (*insert_child)(w);
+    }
 }
 
     
