@@ -16,6 +16,7 @@
 #include <Xm/ColumnP.h>
 #include <Xm/RowColumn.h>
 #include <Xm/Label.h>
+#include "XmI.h"
 #define XK_LATIN1
 #include <X11/keysymdef.h>
 
@@ -214,7 +215,7 @@ static XmPartResource resources[] = {
 	  XmPartOffset(XmBulletinBoard, label_font_list),
 	  XmRImmediate, (XtPointer) NULL },
     { XmNdefaultEntryLabelAlignment, XmCAlignment,
-	  XmRXiAlignment, sizeof(unsigned char),
+	  XmRXmAlignment, sizeof(unsigned char),
 	  offset(default_label_alignment), 
 	  XmRImmediate, (XtPointer) DEFAULT_ALIGNMENT },
 #if 0	/* POSITION HANDLING */
@@ -247,9 +248,9 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNlabelSpacing, sizeof(Dimension), offset(label_spacing),
-      _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels },
+      XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels },
     { XmNitemSpacing, sizeof(Dimension), offset(item_spacing),
-      _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels },
+      XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels },
 };
 #undef offset
 
@@ -260,7 +261,7 @@ static XmPartResource constraint_resources[] = {
 	  offset(label_font_list),
 	  XmRImmediate, (XtPointer) NULL },
     { XmNentryLabelAlignment, XmCAlignment,
-	  XmRXiAlignment, sizeof(unsigned char),
+	  XmRXmAlignment, sizeof(unsigned char),
 	  offset(label_alignment),
 	  XmRImmediate, (XtPointer) XmALIGNMENT_UNSPECIFIED },
 #if 0	/* POSITION HANDLING */
@@ -345,7 +346,7 @@ XmColumnClassRec xiColumnClassRec = {
     /* set_values_almost  */	XtInheritSetValuesAlmost,         
     /* get_values_hook    */	NULL,                             	
     /* accept_focus       */	NULL,                             
-    /* version            */	XtVersionDontCheck,
+    /* version            */	XtVersion,
     /* callback_private   */	NULL,                             
     /* tm_table           */	XtInheritTranslations,
     /* query_geometry     */	(XtGeometryHandler) QueryGeometry, 
@@ -421,6 +422,7 @@ ClassInitialize()
 			    &XmColumn_offsets,
 			    &XmColumnC_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
@@ -430,6 +432,7 @@ ClassInitialize()
         (wc->manager_class.syn_constraint_resources)[i].resource_offset =
             XmGetPartOffset(wc->manager_class.syn_constraint_resources + i,
                             &XmColumnC_offsets);
+    _XmProcessUnlock();
     }
 			    
 
@@ -438,7 +441,7 @@ ClassInitialize()
 		       (XtTypeConverter) CvtStringToLabelPosition,
 		       NULL, 0, XtCacheAll, NULL);
 #endif
-    XtSetTypeConverter(XmRString, XmRXiAlignment,
+    XtSetTypeConverter(XmRString, XmRXmAlignment,
 		       (XtTypeConverter) CvtStringToXiAlignment,
 		       NULL, 0, XtCacheAll, NULL);
     XtSetTypeConverter(XmRString, XmRFillStyle,
@@ -545,7 +548,9 @@ Resize(widget)
     WidgetClass    sc = XtSuperclass(widget);
     XmColumnWidget cw = (XmColumnWidget) widget;
 
+    _XmProcessLock(); 
     (*sc->core_class.resize)(widget);
+    _XmProcessUnlock(); 
 
     Layout(cw, NULL, NULL, -1, -1);
 
@@ -1539,7 +1544,7 @@ CvtStringToLabelPosition(dpy, args, arg_cnt, from, to, data)
  *	CvtStringToXiAlignment(dpy, args, arg_cnt, from, to, data)
  * Description:
  *	This function converts a string representation of the representation
- *	type XmRXiAlignment to an actual value.
+ *	type XmRXnAlignment to an actual value.
  * Input:
  *	dpy     : Display   - unused
  *	args    : XrmValue* - unused
@@ -1589,7 +1594,7 @@ CvtStringToXiAlignment(dpy, args, arg_cnt, from, to, data)
     }
     else
     {
-	XtDisplayStringConversionWarning(dpy, from->addr, XmRXiAlignment);
+	XtDisplayStringConversionWarning(dpy, from->addr, XmRXmAlignment);
 	return( False );
     }
 
@@ -2094,7 +2099,7 @@ VerticalLayout(cw, child, child_size, col_width, col_height)
     Cardinal   i, kidCnt = cw->composite.num_children, j;
     Position   x, y;
     int        cWidth, cMaxWidth, cMinWidth, cHeight, cBorder, cbWidth, cbHeight,
-               lWidth, lHeight, cnt, hExtra, hEach, hLeft, valid, space;
+               lWidth, lHeight, cnt, hExtra, hEach =0 , hLeft = 0, valid, space;
     Dimension  width, height;
     Boolean    change, stretch;
 
