@@ -7,17 +7,12 @@ extern "C" {
 
 #include <Xm/Xm.h>
 #include <Xm/Ext.h>
-#include <Xm/XmExtDefs.h>
 
 extern WidgetClass xmColumnWidgetClass;
 
 typedef struct _XmColumnClassRec * XmColumnWidgetClass;
 typedef struct _XmColumnRec      * XmColumnWidget;
 
-enum { XmFILL_UNSPECIFIED, XmFILL_FLUSH, XmFILL_RAGGED };
-
-enum { XmDISTRIBUTE_TIGHT, XmDISTRIBUTE_SPREAD };
-
 #ifndef XmIsColumn
 #define XmIsColumn(w) (XtIsSubclass(w, xmColumnWidgetClass))
 #endif
