@@ -23,9 +23,7 @@
 
 #include <Xm/Xm.h>
 #include <Xm/XmP.h>
-#if (XmVERSION >= 2)
 #include <Xm/DrawP.h>
-#endif
 
 #include <Xm/ComboBox2P.h>
 
@@ -37,6 +35,7 @@
 #include <Xm/List.h>
 
 #include <Xm/ExtP.h>
+#include "XmI.h"
 
 /*
  * NOTE:  I use the same syntax for popup and popdown that Xt Uses. 
@@ -211,10 +210,10 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNhorizontalMargin, sizeof(Dimension), offset(h_space),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNverticalMargin, sizeof(Dimension), offset(v_space),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
 };
 #undef offset
@@ -247,7 +246,7 @@ XmCombinationBox2ClassRec xmCombinationBox2ClassRec = {
     /* set_values_almost	*/	XtInheritSetValuesAlmost,
     /* get_values_hook		*/	GetValuesHook,
     /* accept_focus		*/	NULL,
-    /* version			*/	XtVersionDontCheck,
+    /* version			*/	XtVersion,
     /* callback_private		*/	NULL,
     /* tm_table			*/	XtInheritTranslations,
     /* query_geometry		*/	(XtGeometryHandler) QueryGeometry,
@@ -351,11 +350,13 @@ ClassInitialize()
 			    &XmCombinationBox2_offsets,
 			    &XmCombinationBox2C_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
 			    &XmCombinationBox2_offsets);
     }
+    _XmProcessUnlock();
 }
 
 /*	Function Name: Initialize
@@ -609,6 +610,11 @@ SetValues(Widget current, Widget request, Widget set,
     }
     XtFree((char *) f_args);
 
+    if (XtIsSensitive((Widget)set_cbw) != XtIsSensitive((Widget)old_cbw))
+      {
+          retval = True;
+      }
+
     if (place_children)
 	{
 	/* figure out the new geometry needed */
@@ -780,7 +786,7 @@ ChangeManaged(Widget w)
     else
 	PlaceChildren(w, False, NULL);
 	
-    _XmNavigChangeManaged(w);	/* for Motif navigation */
+    XmeNavigChangeManaged(w);	/* for Motif navigation */
 }
 
 /*
@@ -879,15 +885,15 @@ ArrowClicked(Widget w, XtPointer combo_ptr, XtPointer info_ptr)
 	if (!XmComboBox2_customized_combo_box(cbw))	
 	    (void) SetTextFromList((Widget) cbw);
 
-	cbdata.reason = XiCR_UPDATE_TEXT;
+	cbdata.reason = XmCR_UPDATE_TEXT;
 	cbdata.event = (arrow == NULL ? NULL : arrow->event);
 	XtCallCallbackList((Widget) cbw, XmComboBox2_update_text_callback(cbw),
 			   (XtPointer) &cbdata);
     }
     else {
-	if (success = PopupList((Widget) cbw))
+	if ((success = PopupList((Widget) cbw)))
 	{
-	    cbdata.reason = XiCR_UPDATE_SHELL;
+	    cbdata.reason = XmCR_UPDATE_SHELL;
 	    cbdata.event = (arrow == NULL ? NULL : arrow->event);
 	    XtCallCallbackList((Widget) cbw, XmComboBox2_update_shell_callback(cbw),
 			       (XtPointer) &cbdata);
@@ -944,8 +950,9 @@ CheckExtensions( XmCombinationBox2WidgetClass combo )
 {
   XmCombinationBox2ClassPartExtension *ret_extension=NULL, *extension;
 
-  extension=
-    (XmCombinationBox2ClassPartExtension *)(combo->combo_class.extension);
+  _XmProcessLock(); 
+  extension= (XmCombinationBox2ClassPartExtension *)(combo->combo_class.extension);
+  _XmProcessUnlock();
 
   while ((ret_extension == NULL) && (extension != NULL)){
     if ((extension->record_type == NULLQUARK) && 
@@ -1016,7 +1023,7 @@ VerifyTextField(Widget w, XtPointer combo_ptr, XtPointer info_ptr)
 	  addition =
 	      CheckExtensions((XmCombinationBox2WidgetClass)XtClass(cbw));
 	  
-	  cbdata.reason = XiCR_VERIFY_TEXT_FAILED;
+	  cbdata.reason = XmCR_VERIFY_TEXT_FAILED;
 	  cbdata.event = (field == NULL ? NULL : field->event);
 	  
 	  XtCallCallbackList((Widget)cbw,
@@ -1063,7 +1070,7 @@ VerifyTextField(Widget w, XtPointer combo_ptr, XtPointer info_ptr)
   
   if (w != NULL)
   {
-      cbdata.reason = XiCR_VERIFY_TEXT;
+      cbdata.reason = XmCR_VERIFY_TEXT;
       cbdata.event = (field == NULL ? NULL : field->event);
       XtCallCallbackList((Widget) cbw,
 			 XmComboBox2_verify_text_callback(cbw),
@@ -1166,8 +1173,8 @@ ListSelected(Widget w, XtPointer cbw_ptr, XtPointer list_data_ptr)
 
     if ((list_data->reason == XmCR_BROWSE_SELECT) &&
 	((list_data->event == NULL) ||
-	 (list_data->event->xany.type != ButtonPress) &&
-	 (list_data->event->xany.type != ButtonRelease)))
+	 ((list_data->event->xany.type != ButtonPress) &&
+	  (list_data->event->xany.type != ButtonRelease))))
     {
 	/* 
 	 * Do not popup list is browse select mode.
@@ -1878,9 +1885,9 @@ PopdownList(Widget w)
     }
     else {
 	XtAppWarningMsg(XtWidgetToApplicationContext(w),
-			XiNnoComboShell, XiNnoComboShell,
+			XmNnoComboShell, XmNnoComboShell,
 			XmCICSWidgetSetError,
-			XiNnoComboShellMsg, NULL, NULL);
+			XmNnoComboShellMsg, NULL, NULL);
     }
 }
 
@@ -1935,8 +1942,8 @@ PopupList(Widget w)
 
     if (shell == NULL) {
 	XtAppWarningMsg(XtWidgetToApplicationContext(w),
-			XiNnoComboShell, XiNnoComboShell, XmCICSWidgetSetError,
-			XiNnoComboShellMsg, NULL, NULL);
+			XmNnoComboShell, XmNnoComboShell, XmCICSWidgetSetError,
+			XmNnoComboShellMsg, NULL, NULL);
 	return(False);
     }
 
@@ -1991,8 +1998,18 @@ PopupList(Widget w)
      * Because of an Xt bug, we need to cal the shell widget's resize
      * proc ourselves.
      */
+    {
+        /* THIS WAS -
+            (*(XtClass(shell)->core_class.resize))(shell);
+        */
+        XtWidgetProc resize;
 
-    (*(XtClass(shell)->core_class.resize))(shell);
+        _XmProcessLock();
+        resize = *(XtClass(shell)->core_class.resize);
+        _XmProcessUnlock();
+
+        (*resize) (shell);
+    }
 
     XGetInputFocus(XtDisplay(shell), 
 		   &(XmComboBox2_focus_owner(cbw)), &(XmComboBox2_focus_state(cbw)));
@@ -2234,9 +2251,9 @@ SetTextFromList(Widget w)
 	    static String strs[] = {"Combination Box", NULL};
 	    Cardinal num = 1;
 	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget) cbw),
-			    XiNstringGetFailed, XiNstringGetFailed,
+			    XmNstringGetFailed, XmNstringGetFailed,
 			    XmCICSWidgetSetError,
-			    XiNstringGetFailedMsg, strs, &num);
+			    XmNstringGetFailedMsg, strs, &num);
 
 	    i++;
 	    continue;
