@@ -14,6 +14,7 @@
 #include <Xm/HierarchyP.h>
 #include <Xm/PushB.h>
 #include <Xm/IconButton.h>
+#include "XmI.h"
 
 /*
  * The bits for the default folder images. 
@@ -144,10 +145,10 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNhorizontalMargin, sizeof(Dimension), offset(h_margin),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNverticalMargin, sizeof(Dimension), offset(v_margin),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
 };
 #undef offset
@@ -169,7 +170,7 @@ static XmPartResource constraints[] = {
 #undef offset
 };
 
-XmHierarchyClassRec xiHierarchyClassRec = {
+XmHierarchyClassRec xmHierarchyClassRec = {
   { /* core fields */
     /* superclass		*/	SUPERCLASS,
     /* class_name		*/	"XmHierarchy",
@@ -197,7 +198,7 @@ XmHierarchyClassRec xiHierarchyClassRec = {
     /* set_values_almost	*/	XtInheritSetValuesAlmost,
     /* get_values_hook		*/	NULL,
     /* accept_focus		*/	NULL,
-    /* version			*/	XtVersionDontCheck,
+    /* version			*/	XtVersion,
     /* callback_private		*/	NULL,
     /* tm_table			*/	defaultTranslations,
     /* query_geometry		*/	NULL,
@@ -241,7 +242,7 @@ XmHierarchyClassRec xiHierarchyClassRec = {
   }
 };
 
-WidgetClass xiHierarchyWidgetClass = (WidgetClass) &xiHierarchyClassRec;
+WidgetClass xmHierarchyWidgetClass = (WidgetClass) &xmHierarchyClassRec;
 
 XmOffsetPtr XmHierarchy_offsets;
 XmOffsetPtr XmHierarchyC_offsets;
@@ -261,18 +262,20 @@ XmOffsetPtr XmHierarchyC_offsets;
 static void 
 ClassInit()
 {
-    XmHierarchyClassRec* wc = &xiHierarchyClassRec;
+    XmHierarchyClassRec* wc = &xmHierarchyClassRec;
     int i;
 
-    XmResolveAllPartOffsets(xiHierarchyWidgetClass,
+    XmResolveAllPartOffsets(xmHierarchyWidgetClass,
 			    &XmHierarchy_offsets,
 			    &XmHierarchyC_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
 			    &XmHierarchy_offsets);
     }
+    _XmProcessUnlock();
 
     XtSetTypeConverter(XmRString, XmRXmHierarchyNodeState,CvtStringToNodeState,
 		       NULL, (Cardinal) 0, XtCacheAll, (XtDestructor) NULL);
@@ -289,6 +292,7 @@ ClassPartInitialize(WidgetClass class)
 {
     XmHierarchyWidgetClass superC, wc = (XmHierarchyWidgetClass) class;
     
+    _XmProcessLock();
     superC = (XmHierarchyWidgetClass)wc->core_class.superclass;
 
 /* 
@@ -331,6 +335,7 @@ ClassPartInitialize(WidgetClass class)
 	wc->hierarchy_class.toggle_node_state = 
 	                            superC->hierarchy_class.toggle_node_state;
     }
+    _XmProcessUnlock();
 }
 
 /*	Function Name: Initialize
@@ -436,10 +441,16 @@ Destroy(Widget w)
 static void 
 InsertChild(Widget w)
 {
+   XtWidgetProc insert_child;
+   
    if (_XmGadgetWarning(w))
        return;
 
-   (*((CompositeWidgetClass) SUPERCLASS)->composite_class.insert_child)(w);
+    _XmProcessLock();
+    insert_child = ((CompositeWidgetClass) SUPERCLASS)->composite_class.insert_child;
+    _XmProcessUnlock();
+    
+   (*insert_child)(w);
 }
 
 /************************************************************
@@ -469,10 +480,10 @@ ConstraintInitialize(Widget req, Widget set, ArgList args, Cardinal * num_args)
 	Cardinal num = 1;
 	
 	XtAppWarningMsg(XtWidgetToApplicationContext(set),
-	 		XiNnodeParentIsSelf,
-			XiNnodeParentIsSelf,
+	 		XmNnodeParentIsSelf,
+			XmNnodeParentIsSelf,
 			XmCICSWidgetSetError,
-			XiNnodeParentIsSelfMsg, msg, &num);
+			XmNnodeParentIsSelfMsg, msg, &num);
 	
 	XmHierarchyC_parent(node) = NULL;
     }
@@ -491,8 +502,14 @@ ConstraintInitialize(Widget req, Widget set, ArgList args, Cardinal * num_args)
 
     XmHierarchyC_open_close_button(node) = NULL;
 
-    if (XmHierarchyC_state(node) != XiNotInHierarchy) {
-	(*(hc->hierarchy_class.reset_open_close_button))((Widget) hw, node);
+    if (XmHierarchyC_state(node) != XmNotInHierarchy) {
+        XmHierarchyResetButtonProc reset_open_close_button;
+
+        _XmProcessLock();
+        reset_open_close_button = hc->hierarchy_class.reset_open_close_button;
+        _XmProcessUnlock();
+
+        (*reset_open_close_button)((Widget) hw, node);
 
 	if (XmHierarchyC_parent(node) == NULL) 
 	    AddChild(XmHierarchy_top_node(hw), node);
@@ -525,7 +542,7 @@ ConstraintDestroy(Widget w)
     HierarchyConstraints node = GetNodeInfo(w);
     XmHierarchyWidget hw = (XmHierarchyWidget) XtParent(w);
 
-    if (XmHierarchyC_state(node) == XiNotInHierarchy) 
+    if (XmHierarchyC_state(node) == XmNotInHierarchy) 
 	return;
 
     /*
@@ -546,8 +563,15 @@ ConstraintDestroy(Widget w)
 	    XtDestroyWidget(XmHierarchyC_open_close_button(node));
 
 	current = 0;
-	(*(hc->hierarchy_class.build_node_table))
-	    ((Widget)hw, XmHierarchy_top_node(hw), &current);
+	{
+	    XmHierarchyBuildTableProc build_node_table;
+
+	    _XmProcessLock();
+	    build_node_table = hc->hierarchy_class.build_node_table;
+	    _XmProcessUnlock();
+
+	    (*build_node_table) ((Widget)hw, XmHierarchy_top_node(hw), &current);
+	}
 
 	XmHierarchy_num_nodes(hw) = current;
     }
@@ -685,10 +709,10 @@ ConstraintSetValues(Widget current, Widget request, Widget set,
 	    Cardinal num = 1;
 
 	    XtAppWarningMsg(XtWidgetToApplicationContext(set),
-			    XiNnodeParentIsSelf,
-			    XiNnodeParentIsSelf,
+			    XmNnodeParentIsSelf,
+			    XmNnodeParentIsSelf,
 			    XmCICSWidgetSetError,
-			    XiNnodeParentIsSelfMsg, msg, &num);
+			    XmNnodeParentIsSelfMsg, msg, &num);
 	    
 	    XmHierarchyC_parent(new_node) = XmHierarchyC_parent(old_node);
 	}
@@ -718,7 +742,15 @@ ConstraintSetValues(Widget current, Widget request, Widget set,
 	XtCallCallbackList((Widget) hw,
 			   XmHierarchy_node_state_beg_end_callback(hw),
 			   (XtPointer) True);
-	(*(hc->hierarchy_class.change_node_state))(new_node);
+	{
+	    XmHierarchyNodeProc change_node_state;
+
+	    _XmProcessLock();
+	    change_node_state = hc->hierarchy_class.change_node_state;
+	    _XmProcessUnlock();
+        
+	    (*change_node_state)(new_node);
+	}
 	XtCallCallbackList((Widget) hw,
 			   XmHierarchy_node_state_beg_end_callback(hw),
 			   (XtPointer) False);
@@ -749,9 +781,15 @@ ChangeNodeState(HierarchyConstraints node)
 	                   XtParent(XmHierarchyC_widget(node));
     XmHierarchyWidgetClass hc = (XmHierarchyWidgetClass) XtClass(hw);
     XmHierarchyNodeStateData node_data;
+    XmHierarchyNodeProc change_node_state;
+    XmHierarchyResetButtonProc reset_open_close_button;
 
-    (*hc->hierarchy_class.reset_open_close_button)
-   	        (XtParent(XmHierarchyC_widget(node)), node);
+    _XmProcessLock();
+    change_node_state = hc->hierarchy_class.change_node_state;
+    reset_open_close_button = hc->hierarchy_class.reset_open_close_button;
+    _XmProcessUnlock();    
+
+    (*reset_open_close_button) (XtParent(XmHierarchyC_widget(node)), node);
 
     node_data.widget = XmHierarchyC_widget(node);
     node_data.state = XmHierarchyC_state(node);
@@ -768,7 +806,7 @@ ChangeNodeState(HierarchyConstraints node)
 		if (XmHierarchyC_state(*childp) == XmOpen) {
 		    XmHierarchyC_state(*childp) = XmClosed;
 		}
-		(*hc->hierarchy_class.change_node_state)(*childp);
+		(*change_node_state)(*childp);
 	    }
 	}
     }
@@ -806,13 +844,19 @@ UnmapAllExtraNodes(Widget w, HierarchyConstraints node)
 {
     register int i;
     XmHierarchyWidgetClass hc = (XmHierarchyWidgetClass) (XtClass(w));
-    register void (*unmap_extra)(Widget, HierarchyConstraints) =
-	hc->hierarchy_class.unmap_all_extra_nodes;
     register int num;
     register HierarchyConstraints * ptr;
 
+    void (*unmap_extra)(Widget, HierarchyConstraints);
+    XmHierarchyNodeProc unmap_node;
+
+    _XmProcessLock();
+    unmap_extra = hc->hierarchy_class.unmap_all_extra_nodes;
+    unmap_node = hc->hierarchy_class.unmap_node;
+    _XmProcessUnlock();
+
     if (XmHierarchyC_status(node) & IS_COMPRESSED)
-	(*(hc->hierarchy_class.unmap_node))(node);
+	(*unmap_node)(node);
 	
     ptr = XmHierarchyC_children(node);
     for (num = XmHierarchyC_num_children(node), i = 0; i < num; i++, ptr++) 
@@ -980,7 +1024,7 @@ ResetOpenCloseButton(Widget w, HierarchyConstraints node)
 	 * widget.
 	 */
 
-        XtSetArg(args[num_args], XmNnodeState, XiNotInHierarchy); num_args++;
+        XtSetArg(args[num_args], XmNnodeState, XmNotInHierarchy); num_args++;
 	XtSetArg(args[num_args], XmNiconPlacement, XmIconOnly); num_args++;
 
 	XmHierarchyC_open_close_button(node) = 
@@ -995,9 +1039,11 @@ ResetOpenCloseButton(Widget w, HierarchyConstraints node)
 	XtSetMappedWhenManaged(XmHierarchyC_open_close_button(node),
 		((XmHierarchyC_status(node) & IS_MAPPED) ? True: False));
 
+	_XmProcessLock();
 	XtAddCallback(XmHierarchyC_open_close_button(node),
 		      XmNactivateCallback,
 		      hc->hierarchy_class.toggle_node_state, (XtPointer) node);
+	_XmProcessUnlock();
     }
     else {
 	XtSetValues(XmHierarchyC_open_close_button(node), args, num_args);
@@ -1022,6 +1068,12 @@ ToggleNodeState(Widget w, XtPointer node_ptr, XtPointer call_data)
     XmHierarchyWidgetClass hc = (XmHierarchyWidgetClass) XtClass((Widget) hw);
     XmHierarchyNodeStateData node_data;
 
+    XmHierarchyNodeProc change_node_state;
+
+    _XmProcessLock();    
+    change_node_state = hc->hierarchy_class.change_node_state;
+    _XmProcessUnlock();
+
     /*
      * Unset the icon button.
      */
@@ -1034,14 +1086,14 @@ ToggleNodeState(Widget w, XtPointer node_ptr, XtPointer call_data)
 			   XmHierarchy_node_state_beg_end_callback(hw),
 			   (XtPointer) True);
 	XmHierarchyC_state(node) = XmClosed;
-	(*(hc->hierarchy_class.change_node_state))((HierarchyConstraints)node);
+	(*change_node_state) ( (HierarchyConstraints) node );
     }
     else if (XmHierarchyC_state(node) == XmClosed) {
 	XtCallCallbackList((Widget) hw,
 			   XmHierarchy_node_state_beg_end_callback(hw),
 			   (XtPointer) True);
 	XmHierarchyC_state(node) = XmOpen;
-	(*(hc->hierarchy_class.change_node_state))((HierarchyConstraints)node);
+	(*change_node_state) ( (HierarchyConstraints) node );
     }
     else
 	return;
@@ -1106,7 +1158,7 @@ CvtStringToNodeState(Display * dpy, XrmValuePtr args, Cardinal *num_args,
     else if (q == XtQEHidden) 
 	type = XmHidden;
     else if (q == XtQENotInHierarchy) 	/* note! shouldn't ever be needed */
-	type = XiNotInHierarchy;
+	type = XmNotInHierarchy;
     else {
 	XtDisplayStringConversionWarning(dpy, fromVal->addr,
 					 XmRXmHierarchyNodeState);
@@ -1282,8 +1334,8 @@ AddChildToList(HierarchyConstraints ** list, Cardinal * num, Cardinal * alloc,
 
 	params[0] = XtName(XmHierarchyC_widget(child));
 	XtAppWarningMsg(XtWidgetToApplicationContext(XmHierarchyC_widget(child)),
-			XiNinsertBeforeNotSibling, XiNinsertBeforeNotSibling, 
-			XmCICSWidgetSetError, XiNinsertBeforeNotSiblingMsg,
+			XmNinsertBeforeNotSibling, XmNinsertBeforeNotSibling, 
+			XmCICSWidgetSetError, XmNinsertBeforeNotSiblingMsg,
 			params, &num);
     }
     
@@ -1375,7 +1427,7 @@ XmHierarchyOpenAllAncestors(Widget nw)
 	{ XmNnodeState, (XtArgVal) XmOpen }
     };
 
-    if (!XtParent(nw) || !XtIsSubclass(XtParent(nw), xiHierarchyWidgetClass))
+    if (!XtParent(nw) || !XtIsSubclass(XtParent(nw), xmHierarchyWidgetClass))
 		return;
 
     node = GetNodeInfo(nw);
@@ -1399,7 +1451,7 @@ WidgetList XmHierarchyGetChildNodes(Widget nw)
     WidgetList retval = (WidgetList)NULL;
     int i;
 
-    if (!XtParent(nw) || !XtIsSubclass(XtParent(nw), xiHierarchyWidgetClass))
+    if (!XtParent(nw) || !XtIsSubclass(XtParent(nw), xmHierarchyWidgetClass))
 		return retval;
 
     node = GetNodeInfo(nw);
