@@ -14,6 +14,7 @@
 
 #include <Xm/IconBoxP.h>
 #include <Xm/ExtP.h>
+#include "XmI.h"
 
 /************************************************************
 *	TYPEDEFS AND DEFINES
@@ -98,16 +99,16 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNhorizontalMargin, sizeof(Dimension), offset(h_margin),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNverticalMargin, sizeof(Dimension), offset(v_margin),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNminimumCellWidth, sizeof(Dimension), offset(min_cell_width),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNminimumCellHeight, sizeof(Dimension), offset(min_cell_height),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
 };
 #undef offset
@@ -151,7 +152,7 @@ XmIconBoxClassRec xmIconBoxClassRec = {
     /* set_values_almost	*/	XtInheritSetValuesAlmost,
     /* get_values_hook		*/	NULL,
     /* accept_focus		*/	NULL,
-    /* version			*/	XtVersionDontCheck,
+    /* version			*/	XtVersion,
     /* callback_private		*/	NULL,
     /* tm_table			*/	XtInheritTranslations,
     /* query_geometry		*/	(XtGeometryHandler) QueryGeometry,
@@ -216,11 +217,13 @@ ClassInitialize()
 			    &XmIconBox_offsets,
 			    &XmIconBoxC_offsets);
     
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
 			    &XmIconBox_offsets);
     }
+    _XmProcessUnlock();
 
 }
 
@@ -487,7 +490,15 @@ InsertChild(Widget w)
    if (_XmGadgetWarning(w))
        return;
 
-   (*((CompositeWidgetClass) SUPERCLASS)->composite_class.insert_child)(w);
+   {
+      XtWidgetProc insert_child;
+
+      _XmProcessLock();
+      insert_child = ( (CompositeWidgetClass) SUPERCLASS)->composite_class.insert_child;
+      _XmProcessUnlock();
+
+      (*insert_child)(w);
+   }
 }
 
 /*	Function Name: ChangeManaged
@@ -521,7 +532,7 @@ ChangeManaged(Widget w)
 	    sprintf(buf, "(%d, %d)", info->cell_x, info->cell_y);
 	    
 	    XtAppWarningMsg(XtWidgetToApplicationContext(w),
-			    XiNcellNotEmpty, XiNcellNotEmpty, 
+			    XmNcellNotEmpty, XmNcellNotEmpty, 
 			    XmCICSWidgetSetError,
 			    XmNcellNotEmptyMsg, params, &num);
 	    /*
@@ -556,7 +567,7 @@ ChangeManaged(Widget w)
 	     */
 	    else if (!SetToEmptyCell(*childp)) {
 		XtAppWarningMsg(XtWidgetToApplicationContext(w),
-				XiNnoEmptyCells, XiNnoEmptyCells,
+				XmNnoEmptyCells, XmNnoEmptyCells,
 				XmCICSWidgetSetError,
 				XmNnoEmptyCellsMsg, NULL, NULL);
 	    }
@@ -568,7 +579,7 @@ ChangeManaged(Widget w)
 
     PlaceChildren(w, NULL);
 
-   _XmNavigChangeManaged(w);	/* For Motif navigation */
+   XmeNavigChangeManaged(w);	/* For Motif navigation */
 }
 
 /*	Function Name: ConstraintInitialize
@@ -631,7 +642,7 @@ ConstraintSetValues(Widget current, Widget request, Widget set,
 	    sprintf(buf, "(%d, %d)", set_info->cell_x, set_info->cell_y);
 
 	    XtAppWarningMsg(XtWidgetToApplicationContext(set),
-			    XiNcellNotEmpty, XiNcellNotEmpty, 
+			    XmNcellNotEmpty, XmNcellNotEmpty, 
 			    XmCICSWidgetSetError,
 			    XmNcellNotEmptyMsg, params, &num);
 
