@@ -10,21 +10,15 @@
 /************************************************************
 *	INCLUDE FILES
 *************************************************************/
-#include <Xm/XmP.h>
-#if (XmVERSION >= 2)
-#include <Xm/DrawP.h>
-#endif
 
+#include <Xm/XmP.h>
+#include <Xm/DrawP.h>
 #include <stdio.h>
 #include <Xm/IconButtonP.h>
-#ifdef VMS
-#include <bitmaps/gray.xbm>
-#else
 #include <X11/bitmaps/gray>
-#endif
-
 #include <Xm/ExtP.h>
 #include "xmlist.h"
+#include "XmI.h"
 
 /************************************************************
 *	TYPEDEFS AND DEFINES
@@ -58,7 +52,7 @@ typedef struct _PixCacheEntry {
 *************************************************************/
 
 #define streq(a, b) (((a) != NULL) && ((b) != NULL) && (strcmp((a), (b)) == 0))
-#define ValidPixmap(p) ((p)!=NULL&&(p)!=XmUNSPECIFIED_PIXMAP)
+#define ValidPixmap(p) ((p)!=None && (p)!=XmUNSPECIFIED_PIXMAP)
 
 /************************************************************
 *	GLOBAL DECLARATIONS
@@ -71,7 +65,9 @@ static XmList pix_cache_list = NULL;
 *	STATIC FUNCTION DECLARATIONS
 *************************************************************/
 
-static void Resize(Widget), Destroy(Widget), ClassInit(void);
+static void Resize(Widget);
+static void Destroy(Widget);
+static void ClassInit(void);
 static void Initialize(Widget, Widget, ArgList, Cardinal *);
 static void Redisplay(Widget, XEvent *, Region);
 static XtGeometryResult QueryGeometry(Widget,
@@ -152,7 +148,7 @@ typedef struct _StippleInfo {
 static StippleInfo *stipple_cache; /* Only one of these for each app. */
 
 static char defaultTranslations[] =
-    "<Btn1Down>,<Btn1Up>:		XiToggle() XiNotify() XiButtonUp()\n\
+    "<Btn1Down>,<Btn1Up>:		XiToggle() XmNotify() XiButtonUp()\n\
      <Btn1Down>:			XiGetFocus() XiToggle() \n\
      <Key>osfSelect:  			XiArmAndActivate()\n\
      <Key>osfActivate:  		XiArmAndActivate()\n\
@@ -184,8 +180,8 @@ static XtActionsRec actionsList[] =
 {
     {"XiArmAndActivate",		ArmAndActivate},
     {"XiToggle",			ToggleState},
-    {"XiNotify",			Notify},
-    {"XiGetFocus",			_XiGetFocus},
+    {"XmNotify",			Notify},
+    {"XiGetFocus",			_XmGetFocus},
     {"XiDoubleNotify",			DoubleNotify}, 
     {"XiButtonUp",			ButtonUp},
     /*
@@ -233,13 +229,6 @@ static XmPartResource resources[] = {
      offset(activate_callback), XmRPointer, (XtPointer) NULL},
   {XmNdoubleClickCallback, XmCCallback, XmRCallback, sizeof(XtCallbackList),
      offset(double_click_callback), XmRPointer, (XtPointer) NULL},
-
-     /* These three are added for BX 5.0 and are not (yet) public
-     ** until it is determined how they interact. For now, usage
-     ** policy is very simple: set them all, or none. This is done
-     ** particularly for Initialize code to avoid GetDesiredSize's call
-     ** to XGetGeometry.
-     */
   {XmNpixmapWidth, XmCDimension, XmRDimension, sizeof(Dimension),
      offset(pix_width), XmRImmediate, (XtPointer) 0},
   {XmNpixmapHeight, XmCDimension, XmRDimension, sizeof(Dimension),
@@ -251,10 +240,10 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNhorizontalMargin, sizeof(Dimension), offset(h_space),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNverticalMargin, sizeof(Dimension), offset(v_space),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNiconTextPadding, sizeof(Dimension), offset(icon_text_padding),
 	  FromPaddingPixels, (XmImportProc) ToPaddingPixels
@@ -293,7 +282,7 @@ XmIconButtonClassRec xiIconButtonClassRec = {
     /* set_values_almost	*/	SetValuesAlmost,
     /* get_values_hook		*/	NULL,
     /* accept_focus		*/	NULL,
-    /* version			*/	XtVersionDontCheck,
+    /* version			*/	XtVersion,
     /* callback_private		*/	NULL,
     /* tm_table			*/	defaultTranslations,
     /* query_geometry		*/	(XtGeometryHandler) QueryGeometry,
@@ -338,11 +327,13 @@ ClassInit()
 			    &XmIconButton_offsets,
 			    NULL);
 
+    _XmProcessLock();
     for(i=0; i<wc->primitive_class.num_syn_resources; i++) {
 	(wc->primitive_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->primitive_class.syn_resources + i,
 			    &XmIconButton_offsets);
     }
+    _XmProcessUnlock();
 
     XtSetTypeConverter(XmRString, XmRXmIconPlacement,
 		       (XtTypeConverter) CvtStringToIconPlacement,
@@ -427,7 +418,7 @@ Initialize(Widget req, Widget set, ArgList args, Cardinal * num_args)
 
     if (XmIconButton_font_list(iw) == NULL)
     {
-        XmIconButton_font_list(iw) = _XmGetDefaultFontList((Widget) iw,
+        XmIconButton_font_list(iw) = XmeGetDefaultRenderTable((Widget) iw,
 						   XmBUTTON_FONTLIST);
     }
 
@@ -530,7 +521,7 @@ Redisplay(Widget w, XEvent * event, Region region)
 
     DrawTextAndImage(w, text_gc, icon_gc, icon_stippled_gc);
 
-    _XmDrawShadows(XtDisplay(w), XtWindow(w), topgc, bottomgc,
+    XmeDrawShadows(XtDisplay(w), XtWindow(w), topgc, bottomgc,
 		   dx, dy, width, height, iw->primitive.shadow_thickness, 
 		   XmSHADOW_OUT);
 
@@ -688,7 +679,7 @@ SetValues(Widget current, Widget request, Widget set,
 	}
 	if( XmIconButton_font_list(set_iw) == NULL )
 	{
-	    XmIconButton_font_list(set_iw) = _XmGetDefaultFontList(set,
+	    XmIconButton_font_list(set_iw) = XmeGetDefaultRenderTable(set,
 							   XmBUTTON_FONTLIST);
 	}
 	XmIconButton_font_list(set_iw) = XmFontListCopy(XmIconButton_font_list(set_iw));
@@ -1249,10 +1240,10 @@ FromPaddingPixels(Widget widget, int offset, XtArgVal *value)
     switch(XmIconButton_icon_placement(iw)) {
     case XmIconTop:
     case XmIconBottom:
-	_XmFromVerticalPixels(widget, offset, value);
+	XmeFromVerticalPixels(widget, offset, value);
 	break;
     default:			/* everything else is horiz. */
-	_XmFromHorizontalPixels(widget, offset, value);
+	XmeFromHorizontalPixels(widget, offset, value);
 	break;
     }
 }
@@ -1274,9 +1265,9 @@ ToPaddingPixels(Widget widget, int offset, XtArgVal *value)
     switch(XmIconButton_icon_placement(iw)) {
     case XmIconTop:
     case XmIconBottom:
-	return(_XmToVerticalPixels(widget, offset, value));
+	return(XmeToVerticalPixels(widget, offset, value));
     default:
-	return(_XmToHorizontalPixels(widget, offset, value));
+	return(XmeToHorizontalPixels(widget, offset, value));
     }
 }
 
