@@ -50,6 +50,7 @@ SOFTWARE.
 #include <Xm/Separator.h>
 
 #include <Xm/ExtP.h>
+#include "XmI.h"
 
 typedef enum {UpLeftPane = 'U',	/* Adjust panes above or to the left.*/
 	      LowRightPane = 'L',/* Adjust panes below or the the right. */
@@ -202,6 +203,9 @@ static XmPartResource resources[] = {
     {XmNsashShadowThickness, XmCShadowThickness, XmRHorizontalDimension,
        sizeof(Dimension), offset(sash_shadow_thickness), XmRImmediate,
        (XtPointer) 2},
+
+    {XmNallowUnusedSpace, XmCAllowUnusedSpace, XmRBoolean, sizeof(Boolean),
+       offset(allow_unused_space), XmRImmediate, (XtPointer) TRUE},
 };
 
 /* Definition for resources that need special processing in get values */
@@ -209,10 +213,10 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNmarginWidth, sizeof(Dimension), offset(margin_width),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNmarginHeight, sizeof(Dimension), offset(margin_height),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNspacing, sizeof(Dimension), offset(internal_bw), 
 	  _XmFromPanedPixels, (XmImportProc) _XmToPanedPixels
@@ -221,13 +225,13 @@ static XmSyntheticResource get_resources[] =
 	  FromPanedOppositePixels, (XmImportProc) ToPanedOppositePixels
     },
     { XmNsashWidth, sizeof(Dimension), offset(sash_width),
-          _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+          XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNsashHeight, sizeof(Dimension), offset(sash_height),
-          _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+          XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNsashShadowThickness, sizeof(Dimension), offset(sash_shadow_thickness),
-          _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+          XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
 };
 #undef offset
@@ -320,7 +324,7 @@ XmPanedClassRec xmPanedClassRec = {
     /* set_values_almost  */   XtInheritSetValuesAlmost,
     /* get_values_hook    */   NULL,
     /* accept_focus       */   NULL,
-    /* version            */   XtVersionDontCheck,
+    /* version            */   XtVersion,
     /* callback_private   */   NULL,
     /* tm_table           */   XtInheritTranslations,
     /* query_geometry	  */   (XtGeometryHandler) QueryGeometry,
@@ -384,6 +388,7 @@ ClassInitialize()
 			    &XmPaned_offsets,
 			    &XmPanedC_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
@@ -394,6 +399,7 @@ ClassInitialize()
             XmGetPartOffset(wc->manager_class.syn_constraint_resources + i,
                             &XmPanedC_offsets);
     }
+    _XmProcessUnlock();
 }
 
 /*	Function Name: AdjustPanedSize
@@ -505,9 +511,9 @@ _XmFromPanedPixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) widget;    
 
     if (IsVert(pw)) 
-	_XmFromVerticalPixels(widget, offset, value);
+	XmeFromVerticalPixels(widget, offset, value);
     else
-	_XmFromHorizontalPixels(widget, offset, value);
+	XmeFromHorizontalPixels(widget, offset, value);
 }
 
 /*	Function Name: FromPanedChildPixels
@@ -526,9 +532,9 @@ FromPanedChildPixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) XtParent(widget);    
 
     if (IsVert(pw)) 
-	_XmFromVerticalPixels(widget, offset, value);
+	XmeFromVerticalPixels(widget, offset, value);
     else
-	_XmFromHorizontalPixels(widget, offset, value);
+	XmeFromHorizontalPixels(widget, offset, value);
 }
 
 /*	Function Name: ToPanedPixels
@@ -546,9 +552,9 @@ _XmToPanedPixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) widget;    
 
     if (IsVert(pw)) 
-	return(_XmToVerticalPixels(widget, offset, value));
+	return(XmeToVerticalPixels(widget, offset, value));
     else
-	return(_XmToHorizontalPixels(widget, offset, value));
+	return(XmeToHorizontalPixels(widget, offset, value));
 }
 
 /*	Function Name: ToPanedChildPixels
@@ -567,9 +573,9 @@ ToPanedChildPixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) XtParent(widget);    
 
     if (IsVert(pw)) 
-	return(_XmToVerticalPixels(widget, offset, value));
+	return(XmeToVerticalPixels(widget, offset, value));
     else
-	return(_XmToHorizontalPixels(widget, offset, value));
+	return(XmeToHorizontalPixels(widget, offset, value));
 }
 
 /*	Function Name: FromPanedOppositePixels
@@ -587,9 +593,9 @@ FromPanedOppositePixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) widget;    
 
     if (IsVert(pw)) 
-	_XmFromHorizontalPixels(widget, offset, value);
+	XmeFromHorizontalPixels(widget, offset, value);
     else
-	_XmFromVerticalPixels(widget, offset, value);
+	XmeFromVerticalPixels(widget, offset, value);
 }
 
 /*	Function Name: ToPanedOppositePixels
@@ -607,9 +613,9 @@ ToPanedOppositePixels(Widget widget, int offset, XtArgVal *value)
     XmPanedWidget pw = (XmPanedWidget) widget;    
 
     if (IsVert(pw)) 
-	return(_XmToHorizontalPixels(widget, offset, value));
+	return(XmeToHorizontalPixels(widget, offset, value));
     else
-	return(_XmToVerticalPixels(widget, offset, value));
+	return(XmeToVerticalPixels(widget, offset, value));
 }
 
 /*	Function Name: PaneSize
@@ -1001,6 +1007,14 @@ RefigureLocations(XmPanedWidget pw, int paneindex, Direction dir)
 	ASSIGN_MIN(pane->size, (int) pane->max);
 	sizeused += pane->size - old;
     }
+
+    if (!XmPaned_allow_unused_space(pw))
+    {
+      if (pane_size > sizeused)
+      {
+        PaneInfo(*NthPane(pw, paneindex-1))->size += (pane_size - sizeused);
+      }
+    }
     
     /*
      * It is possible that the panes will not fit inside the vpaned widget, but
@@ -1529,8 +1543,8 @@ HandleSash(Widget sash, XtPointer junk, XtPointer callData)
 	(action_type == 'S' && call_data->num_params != 1)) 
     {
 	XtAppWarningMsg(XtWidgetToApplicationContext((Widget) pw),
-			XiNbadActionParameters, XiNbadActionParameters,
-			XmCICSWidgetSetError, XiNbadActionParametersMsg, 
+			XmNbadActionParameters, XmNbadActionParameters,
+			XmCICSWidgetSetError, XmNbadActionParametersMsg, 
 			params, &num);
 
 	return;
@@ -1626,9 +1640,9 @@ HandleSash(Widget sash, XtPointer junk, XtPointer callData)
     default:
         {
 	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget) pw),
-			    XiNbadActionParameters, XiNbadActionParameters,
+			    XmNbadActionParameters, XmNbadActionParameters,
 			    XmCICSWidgetSetError,
-			    XiNbadActionParametersMsg, params, &num);
+			    XmNbadActionParametersMsg, params, &num);
 	    
 	    return;
 	}
@@ -1651,7 +1665,7 @@ ManageAndUnmanageSashs(XmPanedWidget pw)
    Widget *managedS, *unmanagedS;
    Widget *childP;
    Cardinal alloc_size;
-   Boolean last_child_has_sash;
+   Boolean last_child_has_sash = False;
 
    alloc_size = (Cardinal) sizeof(Widget) * pw->composite.num_children / 2;
    managedP = managed_sashs = (WidgetList) XtMalloc(alloc_size);
@@ -2143,11 +2157,16 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
  */
 
     if ( !((vert ? CWWidth : CWHeight) & mask))
+    {
         if (vert) 
+        {
 	    request->width = w->core.width;
-	else
+        }
+        else
+        {
 	    request->height = w->core.height;
-
+        }
+    }
     almost = (mask & ~(CWWidth | CWHeight | XtCWQueryOnly));
     almost |= GetRequestInfo(request, !vert) != GetRequestInfo(reply, !vert);
     almost |= GetRequestInfo(request, vert) != GetRequestInfo(reply, vert);
@@ -2299,7 +2318,15 @@ InsertChild(register Widget w)
     * superclass insert_child routine.                                
     */
 
-   (*SuperClass->composite_class.insert_child)(w);
+    {
+        XtWidgetProc insert_child;
+        
+        _XmProcessLock();
+        insert_child = SuperClass->composite_class.insert_child;
+        _XmProcessUnlock();
+
+        (*insert_child)(w);
+    }
 
    /* These should be in Constraint init... */
 
@@ -2439,7 +2466,7 @@ ChangeManaged(Widget w)
    ResetSize(pw, PaneSize(w, IsVert(pw)) <= 1);
    
    /* for Motif navigation */
-   _XmNavigChangeManaged((Widget)pw);
+   XmeNavigChangeManaged((Widget)pw);
 } /* ChangeManaged */
 
 /*	Function Name: ResetSize
@@ -2665,9 +2692,9 @@ SetValues(Widget old, Widget request, Widget set,
 	Cardinal num = 1;
 
 	XtAppWarningMsg(XtWidgetToApplicationContext(set),
-			XiNstaticResource, XiNstaticResource,
+			XmNstaticResource, XmNstaticResource,
 			XmCICSWidgetSetError,
-			XiNstaticResourceMsg, params, &num);
+			XmNstaticResourceMsg, params, &num);
 
 	XmPaned_sash_translations(set_pw) = XmPaned_sash_translations(old_pw);
     }
