@@ -15,12 +15,13 @@
 #include "xmlist.h"
 #include <Xm/TreeP.h>
 #include <X11/Xutil.h>
+#include "XmI.h"
 
 /************************************************************
 *	TYPEDEFS AND DEFINES
 *************************************************************/
 
-#define SUPERCLASS (&xiHierarchyClassRec)
+#define SUPERCLASS (&xmHierarchyClassRec)
 
 #define INDENT_SPACE 30
 
@@ -124,12 +125,12 @@ static void LineStyle_confirm (Widget w, int value);
 #define offset(field) XmPartOffset(XmTree, field)
 
 static XmPartResource resources[] = {
-  {XmNconnectStyle, XmCConnectStyle, XmRXiConnectStyle, 
+  {XmNconnectStyle, XmCConnectStyle, XmRXmConnectStyle, 
        sizeof(XmTreeConnectStyle), offset(connect_style),
        XmRImmediate, (XtPointer) XmTreeDirect},
   {XmNorientation, XmCOrientation, XmROrientation, 
        sizeof(unsigned char), offset(orientation), XmRImmediate, (XtPointer) XmHORIZONTAL},
-  {XmNcompressStyle, XmCCompressStyle, XmRXiCompressStyle, 
+  {XmNcompressStyle, XmCCompressStyle, XmRXmCompressStyle, 
        sizeof(XmTreeCompressStyle), offset(compress_style),
        XmRImmediate, (XtPointer) XmTreeCompressLeaves},
   {XmNverticalDelta, XmCVerticalDelta, XmRVerticalDimension, 
@@ -147,16 +148,16 @@ static XmPartResource resources[] = {
 static XmSyntheticResource get_resources[] =
 {
     { XmNhorizontalNodeSpace, sizeof(Dimension), offset(h_node_space),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
     { XmNverticalNodeSpace, sizeof(Dimension), offset(v_node_space),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNverticalDelta, sizeof(Dimension), offset(vertical_delta),
-	  _XmFromVerticalPixels, (XmImportProc) _XmToVerticalPixels
+	  XmeFromVerticalPixels, (XmImportProc) XmeToVerticalPixels
     },
     { XmNhorizontalDelta, sizeof(Dimension), offset(horizontal_delta),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
 };
 
@@ -172,14 +173,14 @@ static XmPartResource constraints[] = {
        offset(background_color), XmRCallProc, (XtPointer) LineBackgroundColorDefault},
   {XmNlineWidth, XmCLineWidth, XmRInt, sizeof(int),
        offset(line_width), XmRImmediate, (XtPointer) 0},
-  {XmNlineStyle, XmCLineStyle, XmRXiLineStyle, sizeof(int),
+  {XmNlineStyle, XmCLineStyle, XmRXmLineStyle, sizeof(int),
        offset(line_style), XmRImmediate, (XtPointer) LineSolid}
 };
 
 static XmSyntheticResource get_cons_resources[] =
 {
     { XmNopenClosePadding, sizeof(int), offset(open_close_padding),
-	  _XmFromHorizontalPixels, (XmImportProc) _XmToHorizontalPixels
+	  XmeFromHorizontalPixels, (XmImportProc) XmeToHorizontalPixels
     },
 };
 
@@ -213,7 +214,7 @@ XmTreeClassRec xmTreeClassRec = {
     /* set_values_almost	*/	XtInheritSetValuesAlmost,
     /* get_values_hook		*/	NULL,
     /* accept_focus		*/	NULL,
-    /* version			*/	XtVersionDontCheck,
+    /* version			*/	XtVersion,
     /* callback_private		*/	NULL,
     /* tm_table			*/	XtInheritTranslations,
     /* query_geometry		*/	(XtGeometryHandler) QueryGeometry,
@@ -287,6 +288,7 @@ ClassInit(void)
 			    &XmTree_offsets,
 			    &XmTreeC_offsets);
 
+    _XmProcessLock();
     for(i=0; i<wc->manager_class.num_syn_resources; i++) {
 	(wc->manager_class.syn_resources)[i].resource_offset =
 	    XmGetPartOffset(wc->manager_class.syn_resources + i,
@@ -297,14 +299,15 @@ ClassInit(void)
 	    XmGetPartOffset(wc->manager_class.syn_constraint_resources + i,
 			    &XmTreeC_offsets);
     }
+    _XmProcessUnlock();
 
-    XtSetTypeConverter(XmRString, XmRXiConnectStyle,
+    XtSetTypeConverter(XmRString, XmRXmConnectStyle,
 		       (XtTypeConverter) CvtStringToConnectStyle,
 		       NULL, (Cardinal) 0, XtCacheAll, (XtDestructor) NULL);
-    XtSetTypeConverter(XmRString, XmRXiCompressStyle,
+    XtSetTypeConverter(XmRString, XmRXmCompressStyle,
 		       (XtTypeConverter) CvtStringToCompressStyle,
 		       NULL, (Cardinal) 0, XtCacheAll, (XtDestructor) NULL);
-    XtSetTypeConverter(XmRString, XmRXiLineStyle,
+    XtSetTypeConverter(XmRString, XmRXmLineStyle,
 		       (XtTypeConverter) CvtStringToLineStyle,
 		       NULL, (Cardinal) 0, XtCacheNone, (XtDestructor) NULL);
 }
@@ -595,7 +598,7 @@ ChangeManaged(Widget w)
 	}
     }
 
-   _XmNavigChangeManaged(w);	/* for Motif navigation */
+   XmeNavigChangeManaged(w);	/* for Motif navigation */
 }
 
 /*	Function Name: GeometryManager
@@ -691,7 +694,7 @@ ConstraintInitialize(Widget req, Widget set, ArgList args, Cardinal * num_args)
 
     LineStyle_confirm(set, LineSolid);
     
-    if (XmHierarchyC_state(node) != XiNotInHierarchy)
+    if (XmHierarchyC_state(node) != XmNotInHierarchy)
 	GetNodeGCs(set);
     else
  	XmTreeC_gc(node) = None;
@@ -714,7 +717,7 @@ ConstraintDestroy(Widget w)
     XmListElem *elem, *next;
     XmTreeWidget tw;
 
-    if (XmHierarchyC_state(node) == XiNotInHierarchy) 
+    if (XmHierarchyC_state(node) == XmNotInHierarchy) 
     {
       return;
     }
@@ -885,8 +888,13 @@ static void
 ToggleNodeState(Widget w, XtPointer node_ptr, XtPointer call_data)
 {
     Widget tw = XtParent(w);
+    XtCallbackProc toggle_node_state;
+    
+    _XmProcessLock();
+    toggle_node_state = (SUPERCLASS->hierarchy_class.toggle_node_state);
+    _XmProcessUnlock();
 
-    (*(SUPERCLASS->hierarchy_class.toggle_node_state))(w, node_ptr, call_data);
+    (*toggle_node_state)(w, node_ptr, call_data);
     
     CalcLocations(tw, True);
     LayoutChildren(tw, NULL);
@@ -943,7 +951,7 @@ CvtStringToConnectStyle(Display * dpy, XrmValuePtr args, Cardinal *num_args,
     else if ( (q == XtQEDirect) || streq(lowerName,"treedirect") )
 	connect = XmTreeDirect;
     else {
-	XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXiConnectStyle);
+	XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXmConnectStyle);
 	return(FALSE);		/* Conversion failed. */
     }
     
@@ -1003,7 +1011,7 @@ CvtStringToCompressStyle(Display * dpy, XrmValuePtr args, Cardinal *num_args,
     else if ((q == XtQECompressAll) || streq(lowerName,"all") || streq(lowerName,"treecompressall") )
         compress = XmTreeCompressAll;
     else {
-        XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXiCompressStyle);
+        XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXmCompressStyle);
         return(FALSE);          /* Conversion failed. */
     }
 
@@ -1041,7 +1049,7 @@ CvtStringToLineStyle(Display * dpy, XrmValuePtr args, Cardinal *num_args,
     else if ( streq(lowerName, "linedoubledash") || streq(lowerName,"doubledash") )
 	lineStyle = LineDoubleDash;
     else {
-	XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXiLineStyle);
+	XtDisplayStringConversionWarning(dpy,fromVal->addr, XmRXmLineStyle);
 	return(FALSE);		/* Conversion failed. */
     }
     
@@ -1492,9 +1500,13 @@ CalcLocations(Widget w, Boolean resize_it)
 			  &(XmHierarchy_num_nodes(tw)), 0);
 
     current_index = 0;
-    (*(tc->hierarchy_class.build_node_table)) (w, XmHierarchy_top_node(tw),
-					       &current_index);
-
+    {
+        XmHierarchyBuildTableProc build_node_table;
+        _XmProcessLock();
+        build_node_table = tc->hierarchy_class.build_node_table;
+        _XmProcessUnlock();
+        (*build_node_table) (w, XmHierarchy_top_node(tw), &current_index);
+    }
     CalcMaxSize(w);
     FindNodeLocations(w);		/* Finds the location for each node. */
 
@@ -1586,7 +1598,14 @@ LayoutChildren(Widget w, Widget assign_child)
      * Unmap all nodes that no longer are visible.
      */
 
-    (*tc->hierarchy_class.unmap_all_extra_nodes) (w, XmHierarchy_top_node(tw));
+    {
+        XmHierarchyExtraNodeProc unmap_all_extra_nodes;
+
+        _XmProcessLock();
+        unmap_all_extra_nodes = tc->hierarchy_class.unmap_all_extra_nodes;
+        _XmProcessUnlock();
+        (*unmap_all_extra_nodes) (w, XmHierarchy_top_node(tw));
+    }
 
     /*
      * Go through all nodes that can possibly be displayed, putting those
@@ -2102,9 +2121,9 @@ GetNodeHeightAndWidth(Widget w, TreeConstraints node,
       if ((int)XmTreeC_bb_width(node) < (int)l_width)
         XmTreeC_bb_width(node) = l_width;
 
-      if ( ((XmTree_compress_style(tw) == XmTreeCompressAll)
+      if ( (((XmTree_compress_style(tw) == XmTreeCompressAll)
 	        && ((sib_index % 2) == 1))
-	        && (XmHierarchyC_parent(node) != NULL)
+	        && (XmHierarchyC_parent(node) != NULL))
           ||   ((XmTree_compress_style(tw) == XmTreeCompressLeaves)
                 && (num_kids == 0)
 		&& (XmHierarchyC_parent(node) != NULL)
@@ -2307,12 +2326,24 @@ ProcessNode(TreeConstraints node)
     }
     
     if (XmTreeC_map(node)) {
-	(*tc->hierarchy_class.map_node)((HierarchyConstraints) node); 
-	XmTreeC_map(node) = False;
+        XmHierarchyNodeProc map_node;
+
+        _XmProcessLock();
+        map_node = tc->hierarchy_class.map_node;
+        _XmProcessUnlock();
+
+	(*map_node)((HierarchyConstraints) node); 
+    	XmTreeC_map(node) = False;
     }
     
     if (XmTreeC_unmap(node)) {
-	(*tc->hierarchy_class.unmap_node)((HierarchyConstraints) node); 
+	XmHierarchyNodeProc unmap_node;
+
+	_XmProcessLock();
+	unmap_node = tc->hierarchy_class.unmap_node;
+	_XmProcessUnlock();
+
+	(*unmap_node)((HierarchyConstraints) node); 
 	XmTreeC_unmap(node) = False;
     }
 }
