@@ -80,6 +80,7 @@ static char rcsid[] = "$TOG: VendorS.c /main/21 1999/08/09 10:49:41 mgreess $"
 #include "TraversalI.h"
 #include "XmImI.h"
 #include "VendorSI.h"
+#include "EditresComI.h"
 
 #ifndef NO_MESSAGE_CATALOG
 #if !defined(NL_CAT_LOCALE)
@@ -559,8 +560,11 @@ BaseProc(
 
    _XmAppLock(app);
 
-    if (extData = _XmGetWidgetExtData(widget, XmSHELL_EXTENSION))
+    
+    if ((extData = _XmGetWidgetExtData(widget, XmSHELL_EXTENSION)))
+    {
 	secObj = extData->widget;
+    }
 
     _XmAppUnlock(app);
     return secObj;
@@ -629,6 +633,7 @@ ClassInitialize( void )
          need to be created differently.
 ****************************************************************************/
 
+  _XmProcessLock();
   wc_num_res = xmVendorShellExtClassRec.object_class.num_resources;
 
   sc_num_res = xmShellExtClassRec.object_class.num_resources;
@@ -645,16 +650,20 @@ ClassInitialize( void )
   merged_list[i] = uncompiled[i];
 
   }
+  _XmProcessUnlock();
 
+  _XmProcessLock();
   for (i = 0, j = num; i < wc_num_res; i++, j++)
   {
    merged_list[j] =
         xmVendorShellExtClassRec.object_class.resources[i];
   }
+  _XmProcessUnlock();
 
+  _XmProcessLock();
   xmVendorShellExtClassRec.object_class.resources = merged_list;
-  xmVendorShellExtClassRec.object_class.num_resources =
-                wc_num_res + sc_num_res ;
+  xmVendorShellExtClassRec.object_class.num_resources = wc_num_res + sc_num_res ;
+  _XmProcessUnlock();
 
   _XmRegisterConverters();
   _XmRegisterPixmapConverters();
@@ -662,11 +671,20 @@ ClassInitialize( void )
   _XmInitializeExtensions();
   _XmInitializeTraits();
 
-   xmVendorShellExtObjectClass->core_class.class_initialize();
+{
+   XtProc class_initialize;
+   _XmProcessLock();
+   class_initialize = xmVendorShellExtObjectClass->core_class.class_initialize;
+   _XmProcessUnlock();
+   
+   (*class_initialize) ();
+}
    baseClassExtRec.record_type = XmQmotif;
 
    _XmBuildExtResources((WidgetClass) baseClassExtRec.secondaryObjectClass);
 
+    _XmProcessLock();
+
    if (((XmShellExtObjectClass)baseClassExtRec.secondaryObjectClass)->desktop_class.insert_child ==
           XtInheritInsertChild)
        ((XmShellExtObjectClass)baseClassExtRec.secondaryObjectClass)->desktop_class.insert_child =
@@ -687,6 +705,9 @@ ClassInitialize( void )
        ((XmVendorShellExtObjectClass)baseClassExtRec.secondaryObjectClass)->vendor_class.offset_handler =
         ((XmVendorShellExtObjectClass) xmVendorShellExtObjectClass)->vendor_class.offset_handler;
 
+    _XmProcessUnlock();
+
+
    XtFree((char *)uncompiled);
 
 #ifndef NO_MESSAGE_CATALOG
@@ -707,14 +728,22 @@ ClassPartInitialize(
         WidgetClass wc )
 {
     CompositeWidgetClass	compWc = (CompositeWidgetClass)wc;
-    CompositeWidgetClass	superWc = 
-	(CompositeWidgetClass)wc->core_class.superclass;
+
     CompositeClassExtensionRec 	**compExtPtr;
     XmBaseClassExt		*wcePtr, *scePtr;
     XmVendorShellWidgetClass    vc = (XmVendorShellWidgetClass) wc; 
+
+    CompositeWidgetClass	superWc;
+    _XmProcessLock();
+    superWc = (CompositeWidgetClass)wc->core_class.superclass;
+    _XmProcessUnlock();
     
     wcePtr = _XmGetBaseClassExtPtr(wc, XmQmotif);
+
+    _XmProcessLock();
     scePtr = _XmGetBaseClassExtPtr(wc->core_class.superclass, XmQmotif);
+    _XmProcessUnlock();
+
 
     if ( (vc != (XmVendorShellWidgetClass)vendorShellWidgetClass) && 
 	scePtr && *scePtr && 
@@ -727,6 +756,8 @@ ClassPartInitialize(
 	sceClass = (XmVendorShellExtObjectClass)(*scePtr)->
 	    secondaryObjectClass;
 	_XmBuildExtResources((WidgetClass) (*wcePtr)->secondaryObjectClass);
+
+    _XmProcessLock();
 	
 	if (wceClass->desktop_class.insert_child == XtInheritInsertChild)
 	    wceClass->desktop_class.insert_child = 
@@ -749,17 +780,22 @@ ClassPartInitialize(
     compExtPtr = (CompositeClassExtensionRec **) 
 	&(compWc->composite_class.extension);
 
+    _XmProcessUnlock();
+
     compExtPtr = (CompositeClassExtensionRec **)
 	_XmGetClassExtensionPtr( (XmGenericClassExt *) compExtPtr, NULLQUARK);
 
     if (*compExtPtr == NULL) {
 	CompositeClassExtensionRec 	**superExtPtr;
 	
-	superExtPtr = (CompositeClassExtensionRec **) 
-	    &(superWc->composite_class.extension);
+    _XmProcessLock();
+	superExtPtr = (CompositeClassExtensionRec **) &(superWc->composite_class.extension);
+    _XmProcessUnlock();
+
 	superExtPtr = (CompositeClassExtensionRec **)
-	    _XmGetClassExtensionPtr( (XmGenericClassExt *) superExtPtr, 
-				    NULLQUARK);
+                  _XmGetClassExtensionPtr(
+                      (XmGenericClassExt *) superExtPtr,
+                      NULLQUARK);
 
 	*compExtPtr = XtNew(CompositeClassExtensionRec);
 	memcpy((char*)*compExtPtr, (char*)*superExtPtr, 
@@ -767,8 +803,10 @@ ClassPartInitialize(
     }
 
     /* Do this here because of bug in Xt */
+    _XmProcessLock();
     wc->core_class.expose = Redisplay;
-   
+    _XmProcessUnlock();
+
    /* Install the render table trait for all subclasses as well. */
     XmeTraitSet((XtPointer)wc, XmQTspecifyRenderTable, (XtPointer)&vsSRT);
 
@@ -1357,9 +1395,18 @@ GetShellDesktopParent(
 
 		if (XmIsVendorShell(transientParent))
 		{
-			extData = _XmGetWidgetExtData(transientParent,
-				XmSHELL_EXTENSION);
-			desktopParent = (XmDesktopObject)extData->widget;
+			extData = _XmGetWidgetExtData(transientParent, XmSHELL_EXTENSION);
+            if(extData == NULL)
+            {
+#ifdef DEBUG
+                XmeWarning(NULL, "_XmGetWidgetExtData() returned NULL pointer.");
+#endif
+                return desktopParent;
+            }
+            else
+            {
+    			desktopParent = (XmDesktopObject)extData->widget;
+            }
 		}
 	}
 	else if (!XmIsDisplay((Widget)vw))
@@ -1432,7 +1479,10 @@ SecondaryObjectCreate(
 	_XmProcessLock();
 	pePtr = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
 	vec = (*pePtr)->secondaryObjectClass;
+
+    _XmProcessLock();
 	size = vec->core_class.widget_size;
+    _XmProcessUnlock();
 
 	newSec = XtMalloc(size);
 	reqSec = _XmExtObjAlloc(size);
@@ -1448,7 +1498,10 @@ SecondaryObjectCreate(
 	((XmVendorShellExtObject)newSec)->desktop.parent = 
 	    (Widget) desktopParent;
 
+    _XmProcessLock();
 	((XmVendorShellExtObject)newSec)->object.widget_class = vec; 
+    _XmProcessUnlock();
+
 	((XmVendorShellExtObject)newSec)->object.parent = new_w;
 
 	_XmPushWidgetExtData(new_w, extData,
@@ -1457,13 +1510,14 @@ SecondaryObjectCreate(
 	/*
 	 * fetch the resources in superclass to subclass order
 	 */
-
+	_XmProcessLock();
 	XtGetSubresources(new_w,
 			  newSec,
 			  NULL, NULL,
 			  vec->core_class.resources,
 			  vec->core_class.num_resources,
 			  args, *num_args );
+    _XmProcessUnlock();
 
 	memcpy(reqSec, newSec, size);
    
@@ -1546,7 +1600,10 @@ VendorExtInitialize(
 			 (XtPointer)new_w,
 			 XtListHead);
 
+    _XmProcessLock();
     handler = sec->shell_class.structureNotifyHandler;
+    _XmProcessUnlock();
+
     if (handler)
       {
 	  XtInsertEventHandler(extParent, 
@@ -1600,12 +1657,13 @@ VendorExtInitialize(
 		   atoms[XmA_MOTIF_WM_MESSAGES],
 		   &atoms[XmA_MOTIF_WM_OFFSET], 1);
 
+    _XmProcessLock();
     XmAddProtocolCallback( extParent,
 			  atoms[XmA_MOTIF_WM_MESSAGES], 
 			  atoms[XmA_MOTIF_WM_OFFSET],
 			  vec->vendor_class.offset_handler,
 			  (XtPointer) ve);
-    
+    _XmProcessUnlock();
     /*
      * add deleteWindow stuff
      */
@@ -1613,7 +1671,9 @@ VendorExtInitialize(
 
     /* add a post hook for delete response */
 
+    _XmProcessLock();
     delete_window_handler = vec->vendor_class.delete_window_handler;
+    _XmProcessUnlock();
 
     XmSetWMProtocolHooks( extParent, 
 			 atoms[XmAWM_DELETE_WINDOW], NULL, NULL, 
@@ -1779,6 +1839,11 @@ Initialize(
 	 XmDisplay xmDisplay = (XmDisplay) XmGetXmDisplay (XtDisplay(new_w));
 
 	 xmDisplay->display.shellCount += 1;
+
+#ifdef HAVE_LIBXMU
+	XtAddEventHandler(new_w, (EventMask)0, True, (XtEventHandler)_XmEditResCheckMessages, NULL);
+#endif
+
     }
 
     /* install the Motif warning handler that works with XmeWarning */
@@ -1838,7 +1903,10 @@ SetValuesPrehook(
 
     cePtr = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     ec = (*cePtr)->secondaryObjectClass;
+
+    _XmProcessLock();
     extSize = ec->core_class.widget_size;
+    _XmProcessUnlock();
 
     oldExtData = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
     newExtData = (XmWidgetExtData) XtCalloc(1, sizeof(XmWidgetExtDataRec));
@@ -1853,10 +1921,12 @@ SetValuesPrehook(
     memcpy((char *)newExtData->oldWidget, (char *)oldExtData->widget, extSize);
     _XmProcessUnlock();
 
+    _XmProcessLock();
     XtSetSubvalues(oldExtData->widget,
 		    ec->core_class.resources,
 		    ec->core_class.num_resources,
 		    args, *num_args);
+    _XmProcessUnlock();
 
     _XmProcessLock();
     newExtData->reqWidget = (Widget) _XmExtObjAlloc(extSize);
@@ -1864,7 +1934,9 @@ SetValuesPrehook(
     _XmProcessUnlock();
 
     /*  Convert the necessary fields from unit values to pixel values  */
+     _XmProcessLock();
      oldExtData->widget->core.widget_class = ec;
+     _XmProcessUnlock();
     _XmExtImportArgs(oldExtData->widget, args, num_args);
 
     }
@@ -2096,10 +2168,12 @@ GetValuesHook(
 
     if ((ext = _XmGetWidgetExtData(w, XmSHELL_EXTENSION)) != NULL)
     {
+      _XmProcessLock();
       XtGetSubvalues(ext->widget,
 		      ec->core_class.resources,
 		      ec->core_class.num_resources,
 		      args, *num_args);
+      _XmProcessUnlock();
       _XmExtGetValuesHook( ext->widget, args, num_args );
     }
 
@@ -2204,6 +2278,12 @@ Resize(
     XmWidgetExtData	extData;
 
     extData = _XmGetWidgetExtData((Widget)sw, XmSHELL_EXTENSION);
+if(extData == NULL)
+{
+#ifdef DEBUG
+        XmeWarning(NULL, "_XmGetWidgetExtData() returned NULL pointer.");
+#endif
+}
     vendorExt = (XmVendorShellExtObject) extData->widget;
 
     _XmImResize((Widget)sw);
@@ -2237,6 +2317,14 @@ ChangeManaged(
     XtWidgetProc 	change_managed;
 
     extData = _XmGetWidgetExtData((Widget)vw, XmSHELL_EXTENSION);
+
+if(extData == NULL)
+{
+#ifdef DEBUG
+        XmeWarning(NULL, "_XmGetWidgetExtData() returned NULL pointer.");
+#endif
+}
+
     vendorExt = (XmVendorShellExtObject) extData->widget;
 
     for (i= 0; i < vw->composite.num_children; i++)
@@ -2462,13 +2550,25 @@ RootGeometryManager(
 	 XtWidgetGeometry *request,
 	 XtWidgetGeometry *reply )
 {
-    XmWidgetExtData	extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
-    XmShellExtObject	se = (XmShellExtObject)extData->widget;
     XtGeometryHandler	wmGeoHandler;
     ShellWidgetClass	swc = (ShellWidgetClass)wmShellWidgetClass;
     ShellClassExtensionRec **scExtPtr;
     XtGeometryResult	returnVal = XtGeometryNo;
     WMShellWidget	wmShell = (WMShellWidget)w;
+    XmShellExtObject	se;
+
+    XmWidgetExtData	extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
+
+    if(extData == NULL)
+    {
+#ifdef DEBUG
+        XmeWarning(NULL, "_XmGetWidgetExtData() returned NULL pointer.");
+#endif
+        return XtGeometryNo;
+    }
+
+    se = (XmShellExtObject)extData->widget;
+
 
     if (se)
       {
@@ -2479,9 +2579,13 @@ RootGeometryManager(
       XtError("no extension object");
 #endif /* DEBUG */
 
+    _XmProcessLock();
     scExtPtr = (ShellClassExtensionRec **)
-      _XmGetClassExtensionPtr( (XmGenericClassExt *) &(swc->shell_class.extension),
-			       NULLQUARK);
+                    _XmGetClassExtensionPtr(
+                        (XmGenericClassExt *) &(swc->shell_class.extension),
+                        NULLQUARK);
+    _XmProcessUnlock();    
+
     if (request->request_mode & XtCWQueryOnly)
       {
 	   if (!(wmShell->shell.allow_shell_resize) &&
@@ -2721,7 +2825,13 @@ Destroy(
 	     _XmRemoveAllCallbacks((InternalCallbackList *)
 				 &(ve->vendor.focus_moved_callback));
 
-	     xmDesktopClass->core_class.destroy((Widget) ve);
+         {
+         XtWidgetProc destroy;
+         _XmProcessLock();
+         destroy = xmDesktopClass->core_class.destroy;
+         _XmProcessUnlock();
+	     (*destroy) ((Widget) ve);
+         }
 	     XtFree((char *) ve);
 	 }
 	 XtFree((char *) ext);
@@ -2792,6 +2902,15 @@ GetDirection(Widget w)
   XmVendorShellExtObject vendorExt;
 
   extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
+
+  if(extData == NULL)
+  {
+#ifdef DEBUG
+    XmeWarning(NULL, "_XmGetWidgetExtData() returned NULL pointer.");
+#endif
+    return XmRIGHT_TO_LEFT;
+  }
+
   vendorExt = (XmVendorShellExtObject) extData->widget;
   return vendorExt->vendor.layout_direction;
 }
