@@ -58,6 +58,7 @@
 #include <X11/Xatom.h>
 #include <X11/extensions/Print.h>
 #include <Xm/XmStrDefs.h>
+#include <Xm/XmStrDefs22.h>
 #include <Xm/VirtKeys.h>
 #include <Xm/Transfer.h>
 #include <Xm/Primitive.h>
@@ -69,10 +70,10 @@ extern "C" {
 #endif
 
 #define XmVERSION	2
-#define XmREVISION	1
-#define XmUPDATE_LEVEL	30
+#define XmREVISION	2
+#define XmUPDATE_LEVEL	3
 #define XmVersion	(XmVERSION * 1000 + XmREVISION)
-#define XmVERSION_STRING "@(#)Motif Version 2.1.30"
+#define XmVERSION_STRING "@(#)Motif Version 2.2.3"
 
 externalref int xmUseVersion;
 
@@ -381,6 +382,20 @@ enum{   XmLAST_POSITION = -1,           XmFIRST_POSITION
 enum{	XmPOPUP_DISABLED = 0,	XmPOPUP_KEYBOARD = 1,
 	XmPOPUP_AUTOMATIC,	XmPOPUP_AUTOMATIC_RECURSIVE };
 
+/************************************************************************
+ *  Color Selector defines
+ ************************************************************************/
+
+typedef enum { XmListMode = 0, XmScaleMode = 1 } XmColorMode;
+
+/************************************************************************
+ *  Column defines
+ ************************************************************************/
+
+enum { XmFILL_UNSPECIFIED, XmFILL_FLUSH, XmFILL_RAGGED };
+
+enum { XmDISTRIBUTE_TIGHT, XmDISTRIBUTE_SPREAD };
+
 /************************************************************************
  *  ComboBox defines
  ************************************************************************/
@@ -397,6 +412,34 @@ enum{   XmZERO_BASED,		XmONE_BASED
 
 #define XmINVALID_POSITION -1
 
+/************************************************************************
+ *  Icon & Button Box defines
+ ************************************************************************/
+typedef enum { XmIconTop, 
+               XmIconLeft, 
+               XmIconRight, 
+               XmIconBottom,
+               XmIconOnly, 
+               XmIconNone } XmIconPlacement;
+
+typedef enum { XmFillNone, 
+               XmFillMajor, 
+               XmFillMinor, 
+               XmFillAll } XmFillOption;
+
+/************************************************************************
+ * Hierarchy/Tree/Outline defines
+ ************************************************************************/
+typedef enum {XmAlwaysOpen, 
+              XmOpen, 
+              XmClosed, XmHidden,
+	      XmNotInHierarchy} XmHierarchyNodeState;
+
+typedef enum { XmTreeLadder, XmTreeDirect } XmTreeConnectStyle;
+
+typedef enum { XmTreeCompressNone=0, XmTreeCompressLeaves=1,
+               XmTreeCompressAll=2 } XmTreeCompressStyle;
+
 /************************************************************************
  *  Label/Frame defines
  ************************************************************************/
@@ -440,6 +483,35 @@ enum{	XmRESIZE_NONE,			XmRESIZE_GROW,
 	XmRESIZE_ANY
 	} ;
 
+/************************************************************************
+ *  TabBox/TabStack defines
+ ************************************************************************/
+
+typedef enum {XmTABS_SQUARED, XmTABS_ROUNDED, XmTABS_BEVELED} XmTabStyle;
+typedef enum {XmTABS_BASIC, XmTABS_STACKED, XmTABS_STACKED_STATIC,
+              XmTABS_SCROLLED, XmTABS_OVERLAYED} XmTabMode;
+
+typedef enum {XmTAB_ORIENTATION_DYNAMIC, XmTABS_RIGHT_TO_LEFT,
+              XmTABS_LEFT_TO_RIGHT, XmTABS_TOP_TO_BOTTOM,
+              XmTABS_BOTTOM_TO_TOP} XmTabOrientation;
+
+typedef enum {XmTAB_EDGE_TOP_LEFT, XmTAB_EDGE_BOTTOM_RIGHT} XmTabEdge;
+
+typedef enum {XmTAB_ARROWS_ON_RIGHT, XmTAB_ARROWS_ON_LEFT,
+              XmTAB_ARROWS_SPLIT} XmTabArrowPlacement;
+
+enum {XmCR_TAB_SELECTED, XmCR_TAB_UNSELECTED};
+
+typedef enum {XmTABS_ON_TOP, XmTABS_ON_BOTTOM, XmTABS_ON_RIGHT,
+              XmTABS_ON_LEFT} XmTabSide;
+
+typedef enum {XmPIXMAP_TOP, XmPIXMAP_BOTTOM, XmPIXMAP_RIGHT, XmPIXMAP_LEFT,
+              XmPIXMAP_NONE, XmPIXMAP_ONLY} XmPixmapPlacement;
+
+typedef enum {XmTAB_VALUE_COPY, XmTAB_VALUE_SHARE} XmTabValueMode;
+
+typedef enum {XmTAB_CMP_VISUAL, XmTAB_CMP_SIZE, XmTAB_CMP_EQUAL} XmTabResult;
+
 /****************************************************************************
  *  Callback reasons 
  ****************************************************************************/
@@ -480,6 +552,9 @@ enum{	XmCR_NONE,			XmCR_HELP,
 	XmCR_PDM_START_VXAUTH,		XmCR_PDM_START_PXAUTH, 
 	XmCR_PDM_OK,			XmCR_PDM_CANCEL,
 	XmCR_PDM_EXIT_ERROR,
+        XmCR_UPDATE_SHELL,              XmCR_UPDATE_TEXT,
+        XmCR_VERIFY_TEXT,               XmCR_VERIFY_TEXT_FAILED,
+        XmCR_ENTER_CHILD,               XmCR_LEAVE_CHILD,
 	XmCR_PROTOCOLS = 6666 /* required for BC. See CR 9158 */
 	} ;
 
