@@ -12,10 +12,10 @@
 *************************************************************/
 #include <stdio.h>
 #include <X11/IntrinsicP.h>
+
 #include <Xm/XmP.h>
 #include <Xm/PrimitiveP.h>
 #include <Xm/GadgetP.h>
-
 #include <Xm/ExtP.h>
 
 /************************************************************
@@ -39,7 +39,7 @@ typedef struct _PixmapCache {
 *	GLOBAL DECLARATIONS
 *************************************************************/
 
-char _XiVersionString[] = XiVERSION_STRING;
+
 
 String xm_std_filter[] = { XmNx, XmNy, XmNwidth, XmNheight,
 			   XmNdestroyCallback, XmNsensitive, XmNuserData, 
@@ -189,14 +189,14 @@ _XmGadgetWarning(Widget w)
     num = 1;
     
     XtAppWarningMsg(XtWidgetToApplicationContext(w),
-		    XiNnoGadgetSupport, XiNnoGadgetSupport, 
+		    XmNnoGadgetSupport, XmNnoGadgetSupport, 
 		    XmCICSWidgetSetError,
-		    XiNnoGadgetSupportMsg, params, &num);
+		    XmNnoGadgetSupportMsg, params, &num);
     
     return(True); 
 }
 
-/*	Function Name: _XiGetFocus
+/*	Function Name: _XmGetFocus
  *	Description:   Gets the XmFocus.
  *	Arguments:     w - the icon button widget.
  *                     event - the event that caused this action.
@@ -206,7 +206,7 @@ _XmGadgetWarning(Widget w)
 
 /* ARGSUSED */
 void
-_XiGetFocus(Widget w, XEvent * event, String * params, Cardinal * num_params)
+_XmGetFocus(Widget w, XEvent * event, String * params, Cardinal * num_params)
 {
 #ifdef VMS
     if (XtIsRealized(w))
@@ -345,9 +345,7 @@ _XmGetMBStringFromXmString(XmString xmstr)
         switch( type )
 	{
     	case XmSTRING_COMPONENT_TEXT:
-#if (XmVersion >= 1002)
 	case XmSTRING_COMPONENT_LOCALE_TEXT:
-#endif
 	    length += strlen( newText );
 	    break;
  	case XmSTRING_COMPONENT_SEPARATOR:
@@ -425,9 +423,7 @@ _XmGetMBStringFromXmString(XmString xmstr)
         switch( type )
 	{
     	case XmSTRING_COMPONENT_TEXT:
-#if (XmVersion >= 1002)
 	case XmSTRING_COMPONENT_LOCALE_TEXT:
-#endif
 	    strcat(text, newText); 
 	    break;
  	case XmSTRING_COMPONENT_SEPARATOR:
@@ -483,13 +479,9 @@ _XmMoveWidget(Widget w, Position x, Position y)
 void 
 _XmResizeWidget(Widget w, Dimension width, Dimension height, Dimension bw)
 {
-#if (XmVersion > 1001)
     XmDropSiteStartUpdate(w);
     XtResizeWidget(w, width, height, bw);
     XmDropSiteEndUpdate(w);
-#else
-    XtResizeWidget(w, width, height, bw);
-#endif
 }
 
 /*	Function Name: _XmConfigureWidget
@@ -509,13 +501,10 @@ _XmConfigureWidget(Widget w, Position x, Position y,
     if (height < 1) height = 1;
     if (width < 1) width = 1;
 
-#if (XmVersion > 1001)
     XmDropSiteStartUpdate(w);
     XtConfigureWidget(w, x, y, width, height, bw);
     XmDropSiteEndUpdate(w);
-#else
-    XtConfigureWidget(w, x, y, width, height, bw);
-#endif
+
 }
 
 #ifdef notdef
@@ -545,9 +534,9 @@ _XmSetContextData(Widget w, XContext context, XtPointer data)
 
     if (ret != XCSUCCESS) {
 	XtAppErrorMsg(XtWidgetToApplicationContext(w),
-		      XiNcontextSaveFailed, XiNcontextSaveFailed, 
+		      XmNcontextSaveFailed, XmNcontextSaveFailed, 
 		      XmCICSWidgetSetError,
-		      XiNcontextSaveFailedMsg, NULL, NULL);
+		      XmNcontextSaveFailedMsg, NULL, NULL);
     }
 }
 
@@ -615,7 +604,7 @@ _XmDeleteContextData(Widget w, XContext context)
 
 /*
  * Function:
- *	XiCompareISOLatin1(first, second)
+ *	XmCompareISOLatin1(first, second)
  * Description:
  *	Compares two ISO Latin 1 strings to determine if they are equivalent.
  *	Case is not considered for the comparison.
@@ -629,9 +618,9 @@ _XmDeleteContextData(Widget w, XContext context)
  */
 int
 #ifndef _NO_PROTO
-XiCompareISOLatin1(char *first, char *second)
+XmCompareISOLatin1(char *first, char *second)
 #else
-XiCompareISOLatin1(first, second)
+XmCompareISOLatin1(first, second)
     char *first, *second;
 #endif
 {
@@ -762,13 +751,7 @@ XiReleaseStippledPixmap(Screen *screen, Pixmap pixmap)
  *	Boolean - True if the geometry fits the specified widget, else False
  */
 Boolean
-#ifndef _NO_PROTO
 XmCompareXtWidgetGeometryToWidget(XtWidgetGeometry *geom, Widget widget)
-#else
-XmCompareXtWidgetGeometryToWidget(geom, widget)
-    XtWidgetGeometry *geom;
-    Widget           widget;
-#endif
 {
     if( (geom->request_mode & CWX && geom->x != widget->core.x) ||
         (geom->request_mode & CWY && geom->y != widget->core.y) ||
@@ -782,7 +765,7 @@ XmCompareXtWidgetGeometryToWidget(geom, widget)
 
 /*
  * Function:
- *	XiCompareXtWidgetGeometry(geom1, geom2)
+ *	XmCompareXtWidgetGeometry(geom1, geom2)
  * Description:
  *	Compares to XtWidgetGeometry structures to check for equality.
  * Input:
@@ -792,12 +775,7 @@ XmCompareXtWidgetGeometryToWidget(geom, widget)
  *	Boolean - True if both the request_mode and values match, else False
  */
 Boolean
-#ifndef _NO_PROTO
-XiCompareXtWidgetGeometry(XtWidgetGeometry *geom1, XtWidgetGeometry *geom2)
-#else
-XiCompareXtWidgetGeometry(geom1, geom2)
-    XtWidgetGeometry *geom1, *geom2;
-#endif
+XmCompareXtWidgetGeometry(XtWidgetGeometry *geom1, XtWidgetGeometry *geom2)
 {
     if( geom1->request_mode != geom2->request_mode ) return( False );
 
@@ -864,15 +842,9 @@ _XmInitialIzeConverters(Widget w)
  *  FIX for 5178: remove dependency on Xt private data 
  */
 static Boolean
-#ifdef _NO_PROTO
-IsSubclassOf( wc, sc )
-	WidgetClass wc;
-	WidgetClass sc;
-#else
 IsSubclassOf(
 	WidgetClass wc,
 	WidgetClass sc)
-#endif /* _NO_PROTO */
 {
 	WidgetClass p = wc;
 
@@ -887,19 +859,11 @@ IsSubclassOf(
  */
 
 void 
-#ifdef _NO_PROTO
-_XiResolveAllPartOffsets( w_class, offset, constraint_offset, align64 )
-        WidgetClass w_class ;
-        XmOffsetPtr *offset ;
-        XmOffsetPtr *constraint_offset ;
-	Boolean align64;
-#else
 _XiResolveAllPartOffsets(
         WidgetClass w_class,
         XmOffsetPtr *offset,
         XmOffsetPtr *constraint_offset,
 	Boolean     align64)
-#endif /* _NO_PROTO */
 {
     WidgetClass c, super = w_class->core_class.superclass;
     ConstraintWidgetClass cc = NULL, scc = NULL;
@@ -1045,33 +1009,19 @@ _XiResolveAllPartOffsets(
 }
 
 void 
-#ifdef _NO_PROTO
-XiResolveAllPartOffsets( w_class, offset, constraint_offset )
-        WidgetClass w_class ;
-        XmOffsetPtr *offset ;
-        XmOffsetPtr *constraint_offset ;
-#else
 XiResolveAllPartOffsets(
         WidgetClass w_class,
         XmOffsetPtr *offset,
         XmOffsetPtr *constraint_offset )
-#endif /* _NO_PROTO */
 {
     _XiResolveAllPartOffsets( w_class, offset, constraint_offset, False );
 }
 
 void 
-#ifdef _NO_PROTO
-XmResolveAllPartOffsets64( w_class, offset, constraint_offset )
-        WidgetClass w_class ;
-        XmOffsetPtr *offset ;
-        XmOffsetPtr *constraint_offset ;
-#else
 XmResolveAllPartOffsets64(
         WidgetClass w_class,
         XmOffsetPtr *offset,
         XmOffsetPtr *constraint_offset )
-#endif /* _NO_PROTO */
 {
 #ifdef XM_ALIGN_64
     _XiResolveAllPartOffsets( w_class, offset, constraint_offset, True );
@@ -1083,23 +1033,6 @@ XmResolveAllPartOffsets64(
 
 /* -------------------------------------------------------------------------- */
  
-/* more public functions */
-
-XiVersionInfo *XiGetVersionInfo(
-#ifdef _NO_PROTO
-#else
-void
-#endif
-)
-{
-	static XiVersionInfo versionInfo;
-	versionInfo.identifier = XiVersion;
-	versionInfo.version = XiVERSION;
-	versionInfo.revision = XiREVISION;
-	versionInfo.update_level = XiUPDATE_LEVEL;
-	versionInfo.information = XiVERSION_STRING;
-	return &versionInfo;
-}
 
 
 
@@ -1112,13 +1045,8 @@ void
  ************************************************************************/
 
 void 
-#ifdef _NO_PROTO
-_XmExtHighlightBorder( w )
-        Widget w ;
-#else
 _XmExtHighlightBorder(
         Widget w )
-#endif /* _NO_PROTO */
 {
     if(    XmIsPrimitive( w)    ) {   
         (*(xmPrimitiveClassRec.primitive_class.border_highlight))( w) ;
@@ -1131,13 +1059,8 @@ _XmExtHighlightBorder(
 } 
 
 void 
-#ifdef _NO_PROTO
-_XmExtUnhighlightBorder( w )
-        Widget w ;
-#else
 _XmExtUnhighlightBorder(
         Widget w )
-#endif /* _NO_PROTO */
 {
     if(    XmIsPrimitive( w)    )
     {   
