@@ -72,6 +72,17 @@ static char rcsid[] = "$TOG: XmIm.c /main/28 1997/10/13 14:57:31 cshi $"
 # define Va_start(a,b) va_start(a,b)
 
 
+/*
+    On Sun XICProc is not defined. This should be dealt with
+    in the script: configure.ac however 1) not everyone uses that
+    2) AC_CHECK_TYPE(XICProc,,AC_DEFINE(...), include= ?) doesnt
+    work quite right/or is poorly documented and i cant get it to
+    work.
+*/
+#if defined(sun)
+typedef Bool (*XICProc)( XIC, XPointer, XPointer);
+#endif
+
 /* Data structures:
  *	While multiple XIMs are not currently supported, some thought
  * was given to how they might be implemented.  Currently both
@@ -484,6 +495,7 @@ XmImSetFocusValues(Widget w,
       im_info->current_widget = w;
       XtVaGetValues(w, XmNbackground, &bg, NULL);
       XtVaSetValues(p, XmNbackground, bg, NULL);
+      ImGeoReq(p);
       draw_separator(p);
     }
   _XmAppUnlock(app);
@@ -1277,6 +1289,7 @@ set_values(Widget w,
       XtAddEventHandler(p, (EventMask)mask, False, null_proc, NULL);
     }
     if (XtIsRealized(p)) {
+        im_info->current_widget = w;
       if (XmIsDialogShell(p)) {
 	for (i = 0; 
 	     i < ((CompositeWidget)p)->composite.num_children; 
@@ -1287,7 +1300,6 @@ set_values(Widget w,
 	  }
       } else
 	ImGeoReq(p);
-      im_info->current_widget = w;
     }
     /* Is this new XIC supposed to be shared? */
     switch (input_policy)
@@ -1645,6 +1657,8 @@ ImPreeditCaretCallback(XIC xic,
     case XIMAbsolutePosition:
 	pb->caret = data->position;
 	break;
+    default:
+	break;    
   }
 
   proc = get_real_callback((Widget)client_data, PREEDIT_CARET, &real);
@@ -1697,21 +1711,26 @@ regist_real_callback(Widget w,
   register XmImXICInfo icp;
   XmImDisplayInfo xim_info;
   XmImRefRec refs;
-  int i, target;
+  int i, target = 0;
 
   p = w;
   while (!XtIsShell(p))
+  {
     p = XtParent(p);
+  }
 
   xim_info = get_xim_info(p);
-  if ((icp = get_current_xic(xim_info, w)) == NULL){
+  if ((icp = get_current_xic(xim_info, w)) == NULL)
+  {
     return;
   }
 
   refs = icp->widget_refs;
 
-  for (i = 0; i < refs.num_refs; i++){
-    if (refs.refs[i] == w){
+  for (i = 0; i < refs.num_refs; i++)
+  {
+    if (refs.refs[i] == w)
+    {
       target = i;
       break;
     }
@@ -1749,7 +1768,7 @@ set_callback_values(Widget w,
   XIMProc call = value->callback;
   int s = NameToSwitch(name);
   XmInputPolicy ip = input_policy;
-  Widget p;
+  Widget p =NULL;
 
   if (input_policy == XmINHERIT_POLICY){
     p = w;
@@ -2052,10 +2071,18 @@ ImSetGeo(Widget  vw,
 	  rect_preedit.height = icp->sp_height;
         } else if ((use_plist = (icp->input_style & XIMPreeditPosition)) != 0)
         {
-          unsigned int  margin = ((XmPrimitiveWidget)im_info->current_widget)
-                                ->primitive.shadow_thickness
-                            + ((XmPrimitiveWidget)im_info->current_widget)
-                                ->primitive.highlight_thickness;
+        unsigned int  margin;
+        /*
+         * im_info->current_widget eventually contains NULL,
+         * for example, when widget having XIC focus is disposed.
+         * Thus, we should check this and prevent from touching NULL pointer.
+         */
+        if (im_info->current_widget == NULL)
+            break;
+        margin = ((XmPrimitiveWidget)im_info->current_widget)
+            ->primitive.shadow_thickness
+            + ((XmPrimitiveWidget)im_info->current_widget)
+            ->primitive.highlight_thickness;
 
           rect_preedit.width = MIN(icp->preedit_width,
                   XtWidth(im_info->current_widget) - 2*margin);
