@@ -499,7 +499,7 @@ CreateColors(display, attributes, colors, ncolors, image_pixels, mask_pixels,
     /* variables stored in the XpmAttributes structure */
     Visual *visual;
     Colormap colormap;
-    XpmColorSymbol *colorsymbols;
+    XpmColorSymbol *colorsymbols = NULL;
     unsigned int numsymbols;
     XpmAllocColorFunc allocColor;
     void *closure;
@@ -507,7 +507,7 @@ CreateColors(display, attributes, colors, ncolors, image_pixels, mask_pixels,
     char *colorname;
     unsigned int color, key;
     Bool pixel_defined;
-    XpmColorSymbol *symbol;
+    XpmColorSymbol *symbol = NULL;
     char **defaults;
     int ErrorStatus = XpmSuccess;
     char *s;
@@ -2115,6 +2115,7 @@ xpmParseDataAndCreate(display, data, image_return, shapeimage_return,
      * parse extensions
      */
     if (info && (info->valuemask & XpmReturnExtensions))
+    {
 	if (extensions) {
 	    ErrorStatus = xpmParseExtensions(data, &info->extensions,
 					     &info->nextensions);
@@ -2124,6 +2125,7 @@ xpmParseDataAndCreate(display, data, image_return, shapeimage_return,
 	    info->extensions = NULL;
 	    info->nextensions = 0;
 	}
+    }
 
     /*
      * store found informations in the XpmImage structure
