@@ -1,17 +1,12 @@
 #ifndef lint
-static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
+static char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #endif
-#include <stdlib.h>
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
-#define YYLEX yylex()
-#define YYEMPTY -1
-#define yyclearin (yychar=(YYEMPTY))
+#define yyclearin (yychar=(-1))
 #define yyerrok (yyerrflag=0)
-#define YYRECOVERING() (yyerrflag!=0)
-static int yygrowstack();
+#define YYRECOVERING (yyerrflag!=0)
 #define YYPREFIX "yy"
 #line 48 "wmlparse.y"
 
@@ -36,8 +31,7 @@ static int yygrowstack();
 #undef NULL
 #endif
 
-#line 40 "y.tab.c"
-#define YYERRCODE 256
+#line 35 "y.tab.c"
 #define CLASS 1
 #define RESOURCE 2
 #define DATATYPE 3
@@ -90,7 +84,8 @@ static int yygrowstack();
 #define RBRACE 47
 #define STRING 48
 #define ERRORTOKEN 49
-const short yylhs[] = {                                        -1,
+#define YYERRCODE 256
+short yylhs[] = {                                        -1,
     0,    0,    1,    1,    1,    1,    1,    1,    1,    1,
    10,    1,    2,   11,   11,   13,   11,    3,   14,   14,
    16,   14,    4,   17,   17,   19,   17,    5,   20,   20,
@@ -118,7 +113,7 @@ const short yylhs[] = {                                        -1,
   133,  128,  134,  128,  129,  129,  129,  131,  131,  131,
   132,  132,  132,  132,  132,   35,
 };
-const short yylen[] = {                                         2,
+short yylen[] = {                                         2,
     0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
     0,    3,    2,    2,    3,    0,    3,    2,    2,    3,
     0,    3,    2,    2,    3,    0,    3,    2,    2,    3,
@@ -146,7 +141,7 @@ const short yylen[] = {                                         2,
     0,    5,    0,    3,    1,    1,    1,    1,    1,    1,
     1,    1,    1,    1,    1,    1,
 };
-const short yydefred[] = {                                      1,
+short yydefred[] = {                                      1,
     0,   11,    0,    0,    0,    0,    0,    0,    0,    0,
     2,    3,    4,    5,    6,    7,    8,    9,   10,    0,
    16,  256,    0,    0,    0,   21,    0,    0,    0,   31,
@@ -187,7 +182,7 @@ const short yydefred[] = {                                      1,
   100,    0,   98,  102,    0,    0,  127,  108,  103,  105,
     0,    0,  104,  106,
 };
-const short yydgoto[] = {                                       1,
+short yydgoto[] = {                                       1,
    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
    23,   24,   55,   27,   28,   59,   51,   52,   83,   31,
    32,   63,   35,   36,   67,   39,   40,   71,   43,   44,
@@ -203,7 +198,7 @@ const short yydgoto[] = {                                       1,
   184,  320,  241,  121,   82,  155,  146,  156,  157,  288,
   158,  252,  289,  186,
 };
-const short yysindex[] = {                                      0,
+short yysindex[] = {                                      0,
   116,    0,  -24,   -3,   12,   65,   81,   87,   93,   95,
     0,    0,    0,    0,    0,    0,    0,    0,    0,  -18,
     0,    0,  -20,  -11,   -1,    0,  -20,    2,   59,    0,
@@ -244,7 +239,7 @@ const short yysindex[] = {                                      0,
     0,  326,    0,    0,  325,  176,    0,    0,    0,    0,
   327,  330,    0,    0,
 };
-const short yyrindex[] = {                                      0,
+short yyrindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    7,    0,    0,    0,   15,    0,    0,    0,
@@ -285,7 +280,7 @@ const short yyrindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,
 };
-const short yygindex[] = {                                      0,
+short yygindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,  266,    0,    0,  289,    0,    0,  315,    0,    0,
   358,    0,    0,  255,    0,    0,  293,    0,    0,  348,
@@ -302,7 +297,7 @@ const short yygindex[] = {                                      0,
     0,    0,    0,    0,
 };
 #define YYTABLESIZE 473
-const short yytable[] = {                                      29,
+short yytable[] = {                                      29,
    33,   37,   41,   45,   49,   53,   13,   13,   13,   13,
    13,   13,   13,   13,   18,   18,   18,   18,   18,   18,
    18,   18,   29,   22,  359,   54,   33,   22,  103,  360,
@@ -352,7 +347,7 @@ const short yytable[] = {                                      29,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,  147,
 };
-const short yycheck[] = {                                       4,
+short yycheck[] = {                                       4,
     5,    6,    7,    8,    9,   10,    0,    1,    2,    3,
     4,    5,    6,    7,    0,    1,    2,    3,    4,    5,
     6,    7,   27,   48,   11,   44,   31,   48,   46,   16,
@@ -408,7 +403,7 @@ const short yycheck[] = {                                       4,
 #endif
 #define YYMAXTOKEN 52
 #if YYDEBUG
-const char * const yyname[] = {
+char *yyname[] = {
 "end-of-file","CLASS","RESOURCE","DATATYPE","CONTROLLIST","ENUMERATIONSET",
 "ENUMERATIONVALUE","CHARACTERSET","DOCNAME","CONVFUNC","ALIAS","TYPE",
 "RESOURCELITERAL","RELATED","INTERNALLITERAL","XRMRESOURCE","EXCLUDE",
@@ -419,7 +414,7 @@ const char * const yyname[] = {
 "RIGHTTOLEFT","ONEBYTE","TWOBYTE","MIXED1_2BYTE","COLON","SEMICOLON","EQUALS",
 "LBRACE","RBRACE","STRING","ERRORTOKEN","CHILD","CHILDREN","PARENTCLASS",
 };
-const char * const yyrule[] = {
+char *yyrule[] = {
 "$accept : statement_block_list",
 "statement_block_list :",
 "statement_block_list : statement_block_list statement_block",
@@ -682,9 +677,6 @@ const char * const yyrule[] = {
 #ifndef YYSTYPE
 typedef int YYSTYPE;
 #endif
-#if YYDEBUG
-#include <stdio.h>
-#endif
 #ifdef YYSTACKSIZE
 #undef YYMAXDEPTH
 #define YYMAXDEPTH YYSTACKSIZE
@@ -692,11 +684,10 @@ typedef int YYSTYPE;
 #ifdef YYMAXDEPTH
 #define YYSTACKSIZE YYMAXDEPTH
 #else
-#define YYSTACKSIZE 10000
-#define YYMAXDEPTH 10000
+#define YYSTACKSIZE 500
+#define YYMAXDEPTH 500
 #endif
 #endif
-#define YYINITSTACKSIZE 200
 int yydebug;
 int yynerrs;
 int yyerrflag;
@@ -705,11 +696,10 @@ short *yyssp;
 YYSTYPE *yyvsp;
 YYSTYPE yyval;
 YYSTYPE yylval;
-short *yyss;
-short *yysslim;
-YYSTYPE *yyvs;
-int yystacksize;
-#line 746 "wmlparse.y"
+short yyss[YYSTACKSIZE];
+YYSTYPE yyvs[YYSTACKSIZE];
+#define yystacksize YYSTACKSIZE
+#line 747 "wmlparse.y"
 
 /*
  * Dummmy error routine, since we output our own.
@@ -723,73 +713,20 @@ char *s;
 
 #include "wmllex.c"
 
-#line 727 "y.tab.c"
-/* allocate initial stack or double stack size, up to YYMAXDEPTH */
-static int yygrowstack()
-{
-    int newsize, i;
-    short *newss;
-    YYSTYPE *newvs;
-
-    if ((newsize = yystacksize) == 0)
-        newsize = YYINITSTACKSIZE;
-    else if (newsize >= YYMAXDEPTH)
-        return -1;
-    else if ((newsize *= 2) > YYMAXDEPTH)
-        newsize = YYMAXDEPTH;
-    i = yyssp - yyss;
-    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
-      (short *)malloc(newsize * sizeof *newss);
-    if (newss == NULL)
-        return -1;
-    yyss = newss;
-    yyssp = newss + i;
-    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
-      (YYSTYPE *)malloc(newsize * sizeof *newvs);
-    if (newvs == NULL)
-        return -1;
-    yyvs = newvs;
-    yyvsp = newvs + i;
-    yystacksize = newsize;
-    yysslim = yyss + newsize - 1;
-    return 0;
-}
-
+#line 717 "y.tab.c"
 #define YYABORT goto yyabort
 #define YYREJECT goto yyabort
 #define YYACCEPT goto yyaccept
 #define YYERROR goto yyerrlab
-
-#ifndef YYPARSE_PARAM
-#if defined(__cplusplus) || __STDC__
-#define YYPARSE_PARAM_ARG void
-#define YYPARSE_PARAM_DECL
-#else	/* ! ANSI-C/C++ */
-#define YYPARSE_PARAM_ARG
-#define YYPARSE_PARAM_DECL
-#endif	/* ANSI-C/C++ */
-#else	/* YYPARSE_PARAM */
-#ifndef YYPARSE_PARAM_TYPE
-#define YYPARSE_PARAM_TYPE void *
-#endif
-#if defined(__cplusplus) || __STDC__
-#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL
-#else	/* ! ANSI-C/C++ */
-#define YYPARSE_PARAM_ARG YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
-#endif	/* ANSI-C/C++ */
-#endif	/* ! YYPARSE_PARAM */
-
 int
-yyparse (YYPARSE_PARAM_ARG)
-    YYPARSE_PARAM_DECL
+yyparse()
 {
     register int yym, yyn, yystate;
 #if YYDEBUG
-    register const char *yys;
+    register char *yys;
+    extern char *getenv();
 
-    if ((yys = getenv("YYDEBUG")))
+    if (yys = getenv("YYDEBUG"))
     {
         yyn = *yys;
         if (yyn >= '0' && yyn <= '9')
@@ -801,13 +738,12 @@ yyparse (YYPARSE_PARAM_ARG)
     yyerrflag = 0;
     yychar = (-1);
 
-    if (yyss == NULL && yygrowstack()) goto yyoverflow;
     yyssp = yyss;
     yyvsp = yyvs;
     *yyssp = yystate = 0;
 
 yyloop:
-    if ((yyn = yydefred[yystate])) goto yyreduce;
+    if (yyn = yydefred[yystate]) goto yyreduce;
     if (yychar < 0)
     {
         if ((yychar = yylex()) < 0) yychar = 0;
@@ -830,7 +766,7 @@ yyloop:
             printf("%sdebug: state %d, shifting to state %d\n",
                     YYPREFIX, yystate, yytable[yyn]);
 #endif
-        if (yyssp >= yysslim && yygrowstack())
+        if (yyssp >= yyss + yystacksize - 1)
         {
             goto yyoverflow;
         }
@@ -847,12 +783,12 @@ yyloop:
         goto yyreduce;
     }
     if (yyerrflag) goto yyinrecovery;
-#if defined(lint) || defined(__GNUC__)
+#ifdef lint
     goto yynewerror;
 #endif
 yynewerror:
     yyerror("syntax error");
-#if defined(lint) || defined(__GNUC__)
+#ifdef lint
     goto yyerrlab;
 #endif
 yyerrlab:
@@ -871,7 +807,7 @@ yyinrecovery:
                     printf("%sdebug: state %d, error recovery shifting\
  to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
 #endif
-                if (yyssp >= yysslim && yygrowstack())
+                if (yyssp >= yyss + yystacksize - 1)
                 {
                     goto yyoverflow;
                 }
@@ -1019,310 +955,310 @@ case 81:
 { yytknval1 = DIALOGCLASS; }
 break;
 case 82:
-#line 345 "wmlparse.y"
+#line 346 "wmlparse.y"
 { yytknval2 = ATTRTRUE; }
 break;
 case 83:
-#line 346 "wmlparse.y"
+#line 347 "wmlparse.y"
 { yytknval2 = ATTRFALSE; }
 break;
 case 88:
-#line 357 "wmlparse.y"
+#line 358 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 92:
-#line 367 "wmlparse.y"
+#line 368 "wmlparse.y"
 { wmlAddClassResource (yynameval); }
 break;
 case 94:
-#line 370 "wmlparse.y"
+#line 371 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 99:
-#line 377 "wmlparse.y"
+#line 378 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 103:
-#line 389 "wmlparse.y"
+#line 390 "wmlparse.y"
 { wmlAddClassResourceAttribute (yytknval1, yystringval); }
 break;
 case 105:
-#line 394 "wmlparse.y"
+#line 395 "wmlparse.y"
 { wmlAddClassResourceAttribute (yytknval1, yytknval2); }
 break;
 case 107:
-#line 396 "wmlparse.y"
+#line 397 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 109:
-#line 400 "wmlparse.y"
+#line 401 "wmlparse.y"
 { yytknval1 = TYPE; }
 break;
 case 110:
-#line 401 "wmlparse.y"
+#line 402 "wmlparse.y"
 { yytknval1 = DEFAULT; }
 break;
 case 111:
-#line 405 "wmlparse.y"
+#line 406 "wmlparse.y"
 { yytknval1 = EXCLUDE; }
 break;
 case 116:
-#line 416 "wmlparse.y"
+#line 417 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 120:
-#line 426 "wmlparse.y"
+#line 427 "wmlparse.y"
 { wmlAddClassControl (yynameval); }
 break;
 case 122:
-#line 429 "wmlparse.y"
+#line 430 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 126:
-#line 435 "wmlparse.y"
+#line 436 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 132:
-#line 446 "wmlparse.y"
+#line 447 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 136:
-#line 456 "wmlparse.y"
+#line 457 "wmlparse.y"
 { wmlAddClassChild (yynameval); }
 break;
 case 138:
-#line 458 "wmlparse.y"
+#line 459 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 140:
-#line 470 "wmlparse.y"
+#line 471 "wmlparse.y"
 { wmlCreateResource (yynameval, yytknval1); }
 break;
 case 142:
-#line 475 "wmlparse.y"
+#line 476 "wmlparse.y"
 { yytknval1 = ARGUMENT; }
 break;
 case 143:
-#line 476 "wmlparse.y"
+#line 477 "wmlparse.y"
 { yytknval1 = REASON; }
 break;
 case 144:
-#line 477 "wmlparse.y"
+#line 478 "wmlparse.y"
 { yytknval1 = CONSTRAINT; }
 break;
 case 145:
-#line 478 "wmlparse.y"
+#line 479 "wmlparse.y"
 { yytknval1 = SUBRESOURCE; }
 break;
 case 149:
-#line 485 "wmlparse.y"
+#line 486 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 153:
-#line 497 "wmlparse.y"
+#line 498 "wmlparse.y"
 { wmlAddResourceAttribute (yytknval1, yystringval); }
 break;
 case 155:
-#line 502 "wmlparse.y"
+#line 503 "wmlparse.y"
 { wmlAddResourceAttribute (yytknval1, yytknval2); }
 break;
 case 157:
-#line 504 "wmlparse.y"
+#line 505 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 159:
-#line 508 "wmlparse.y"
+#line 509 "wmlparse.y"
 { yytknval1 = TYPE; }
 break;
 case 160:
-#line 509 "wmlparse.y"
+#line 510 "wmlparse.y"
 { yytknval1 = RESOURCELITERAL; }
 break;
 case 161:
-#line 510 "wmlparse.y"
+#line 511 "wmlparse.y"
 { yytknval1 = ENUMERATIONSET; }
 break;
 case 162:
-#line 511 "wmlparse.y"
+#line 512 "wmlparse.y"
 { yytknval1 = INTERNALLITERAL; }
 break;
 case 163:
-#line 512 "wmlparse.y"
+#line 513 "wmlparse.y"
 { yytknval1 = RELATED; }
 break;
 case 164:
-#line 513 "wmlparse.y"
+#line 514 "wmlparse.y"
 { yytknval1 = DOCNAME; }
 break;
 case 165:
-#line 514 "wmlparse.y"
+#line 515 "wmlparse.y"
 { yytknval1 = DEFAULT; }
 break;
 case 166:
-#line 515 "wmlparse.y"
+#line 516 "wmlparse.y"
 { yytknval1 = ALIAS; }
 break;
 case 167:
-#line 519 "wmlparse.y"
+#line 520 "wmlparse.y"
 { yytknval1 = XRMRESOURCE; }
 break;
 case 168:
-#line 528 "wmlparse.y"
+#line 529 "wmlparse.y"
 { wmlCreateChild(yynameval, yystringval); }
 break;
 case 169:
-#line 537 "wmlparse.y"
+#line 538 "wmlparse.y"
 { wmlCreateDatatype (yystringval); }
 break;
 case 174:
-#line 545 "wmlparse.y"
+#line 546 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 178:
-#line 557 "wmlparse.y"
+#line 558 "wmlparse.y"
 { wmlAddDatatypeAttribute (yytknval1, yystringval); }
 break;
 case 180:
-#line 559 "wmlparse.y"
+#line 560 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 182:
-#line 563 "wmlparse.y"
+#line 564 "wmlparse.y"
 { yytknval1 = INTERNALLITERAL; }
 break;
 case 183:
-#line 564 "wmlparse.y"
+#line 565 "wmlparse.y"
 { yytknval1 = DOCNAME; }
 break;
 case 184:
-#line 565 "wmlparse.y"
+#line 566 "wmlparse.y"
 { yytknval1 = XRMRESOURCE; }
 break;
 case 185:
-#line 575 "wmlparse.y"
+#line 576 "wmlparse.y"
 { wmlCreateOrAppendCtrlList (yynameval); }
 break;
 case 190:
-#line 583 "wmlparse.y"
+#line 584 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 194:
-#line 593 "wmlparse.y"
+#line 594 "wmlparse.y"
 { wmlAddCtrlListControl (yynameval); }
 break;
 case 196:
-#line 596 "wmlparse.y"
+#line 597 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 200:
-#line 602 "wmlparse.y"
+#line 603 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 202:
-#line 614 "wmlparse.y"
+#line 615 "wmlparse.y"
 { wmlCreateEnumSet (yynameval, yystringval); }
 break;
 case 208:
-#line 627 "wmlparse.y"
+#line 628 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 212:
-#line 637 "wmlparse.y"
+#line 638 "wmlparse.y"
 { wmlAddEnumSetValue (yynameval); }
 break;
 case 214:
-#line 639 "wmlparse.y"
+#line 640 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 216:
-#line 650 "wmlparse.y"
+#line 651 "wmlparse.y"
 { wmlCreateEnumValue (yynameval); }
 break;
 case 221:
-#line 658 "wmlparse.y"
+#line 659 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 225:
-#line 670 "wmlparse.y"
+#line 671 "wmlparse.y"
 { wmlAddEnumValueAttribute (yytknval1, yystringval); }
 break;
 case 227:
-#line 672 "wmlparse.y"
+#line 673 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 229:
-#line 676 "wmlparse.y"
+#line 677 "wmlparse.y"
 { yytknval1 = ENUMLITERAL; }
 break;
 case 230:
-#line 686 "wmlparse.y"
+#line 687 "wmlparse.y"
 { wmlCreateCharset (yystringval); }
 break;
 case 235:
-#line 694 "wmlparse.y"
+#line 695 "wmlparse.y"
 { LexIssueError(RBRACE); }
 break;
 case 239:
-#line 706 "wmlparse.y"
+#line 707 "wmlparse.y"
 { wmlAddCharsetAttribute (yytknval1, yystringval); }
 break;
 case 241:
-#line 711 "wmlparse.y"
+#line 712 "wmlparse.y"
 { wmlAddCharsetAttribute (yytknval1, yytknval2); }
 break;
 case 243:
-#line 713 "wmlparse.y"
+#line 714 "wmlparse.y"
 { LexIssueError(SEMICOLON); }
 break;
 case 245:
-#line 717 "wmlparse.y"
+#line 718 "wmlparse.y"
 { yytknval1 = INTERNALLITERAL; }
 break;
 case 246:
-#line 718 "wmlparse.y"
+#line 719 "wmlparse.y"
 { yytknval1 = ALIAS; }
 break;
 case 247:
-#line 719 "wmlparse.y"
+#line 720 "wmlparse.y"
 { yytknval1 = XMSTRINGCHARSETNAME; }
 break;
 case 248:
-#line 723 "wmlparse.y"
+#line 724 "wmlparse.y"
 { yytknval1 = DIRECTION; }
 break;
 case 249:
-#line 724 "wmlparse.y"
+#line 725 "wmlparse.y"
 { yytknval1 = PARSEDIRECTION; }
 break;
 case 250:
-#line 725 "wmlparse.y"
+#line 726 "wmlparse.y"
 { yytknval1 = CHARACTERSIZE; }
 break;
 case 251:
-#line 729 "wmlparse.y"
+#line 730 "wmlparse.y"
 { yytknval2 = LEFTTORIGHT; }
 break;
 case 252:
-#line 730 "wmlparse.y"
+#line 731 "wmlparse.y"
 { yytknval2 = RIGHTTOLEFT; }
 break;
 case 253:
-#line 731 "wmlparse.y"
+#line 732 "wmlparse.y"
 { yytknval2 = ONEBYTE; }
 break;
 case 254:
-#line 732 "wmlparse.y"
+#line 733 "wmlparse.y"
 { yytknval2 = TWOBYTE; }
 break;
 case 255:
-#line 733 "wmlparse.y"
+#line 734 "wmlparse.y"
 { yytknval2 = MIXED1_2BYTE; }
 break;
 case 256:
-#line 742 "wmlparse.y"
+#line 743 "wmlparse.y"
 { strcpy (yynameval, (XmConst char *)yystringval); }
 break;
-#line 1326 "y.tab.c"
+#line 1262 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
@@ -1365,7 +1301,7 @@ break;
         printf("%sdebug: after reduction, shifting from state %d \
 to state %d\n", YYPREFIX, *yyssp, yystate);
 #endif
-    if (yyssp >= yysslim && yygrowstack())
+    if (yyssp >= yyss + yystacksize - 1)
     {
         goto yyoverflow;
     }
